Test Report

# Summary

Started | 2025-09-10 17:12:35
Ended | 2025-09-10 17:21:54
Duration | 0:09:19.270071
Total run time | 0:09:00.681885

100 passed 5 skipped

# Warnings

## Warnings 189

- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/cli.py:205
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:98
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:102
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:73
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:67
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:115
- RuntimeWarning No digital elevation model provided. Note that this may cause uncertainties, e.g., in the atmospheric correction and the orthorectification.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_config.py:107
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/polymer_enmap.py:53
- DeprecationWarning 'pkgutil.get_loader' is deprecated and slated for removal in Python 3.14; use importlib.util.find_spec() instead
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/acwater/level1_enmap.py:67
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Automatic nodata value detection returned the value 0.0 for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER' but this seems to be unreliable (occurs in only 2 image corners). To avoid automatic detection, just pass the correct nodata value.
  /opt/conda/envs/ci_env/lib/python3.12/site-packages/geoarray/baseclasses.py:806
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- UserWarning Unable to run EnPT on 32 CPU cores as there are only 24 available. Falling back to 24 cores.
  /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/options/config.py:407
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66
- DeprecationWarning This process (pid=167) is multi-threaded, use of fork() may lead to deadlocks in the child.
  /opt/conda/envs/ci_env/lib/python3.12/multiprocessing/popen_fork.py:66

# Tests

## tests/test_cli_parser.py 7 0:00:00.736583

### PASSED Test_CLIParser::test_json_opts 0:00:00.193766

Started | 2025-09-10 17:12:50
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.193766
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_output_nodata_value 0:00:00.122133

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.122133
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_acceptance 0:00:00.081731

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.081731
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_boolean 0:00:00.129929

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.129929
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_param_list 0:00:00.045822

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.045822
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtepsg 0:00:00.081104

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.081104
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_CLIParser::test_tgtprj 0:00:00.082099

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.082099
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_config.py 13 0:00:00.376768

### PASSED Test_get_options::test_target_is_file_no_validation 0:00:00.008470

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.008470
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_get_options::test_target_is_file_validation 0:00:00.016743

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.016743
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_invalid_filepath 0:00:00.036904

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.036904
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_file 0:00:00.043740

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.043740
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_param_acceptance 0:00:00.036141

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.036141
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_allfine 0:00:00.036134

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.036134
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_badcomment 0:00:00.017344

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.017344
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_nojson 0:00:00.017538

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.017538
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_schema_violation 0:00:00.026734

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.026734
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_jsonconfig_str_undecodable_val 0:00:00.017639

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.017639
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_plain_args 0:00:00.036646

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.036646
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_dict_validity 0:00:00.045701

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:51
Duration | 0:00:00.045701
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPTConfig::test_to_jsonable_dict 0:00:00.037034

Started | 2025-09-10 17:12:51
Ended | 2025-09-10 17:12:52
Duration | 0:00:00.037034
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_controller.py 5 0:03:09.492960

### PASSED Test_EnPT_Controller::test_run_all_processors 0:00:08.412111

Started | 2025-09-10 17:12:52
Ended | 2025-09-10 17:13:00
Duration | 0:00:08.412111
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': True,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': True,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/dem_map_geo.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest1_CWV2_SM0.zip',
                      'path_l1b_enmap_image_gapfill': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/AlpineTest2_CWV2_SM0.zip',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpljmwchsg'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': False,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/10 17:12:52:   Reading metadata for VNIR detector...
    2025/09/10 17:12:52:   Calculating solar irradiance...
    2025/09/10 17:12:52:   Reading metadata for SWIR detector...
    2025/09/10 17:12:53:   Calculating solar irradiance...
    2025/09/10 17:12:53:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:12:53:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:12:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:12:53:   Reading metadata for VNIR detector...
    2025/09/10 17:12:53:   Calculating solar irradiance...
    2025/09/10 17:12:53:   Reading metadata for SWIR detector...
    2025/09/10 17:12:53:   Calculating solar irradiance...
    2025/09/10 17:12:53:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:12:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:12:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:12:54:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:12:54:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:12:54:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:12:54:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:12:54:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:12:55:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:12:55:   Skipping atmospheric correction as configured and computing top-of-atmosphere reflectance instead.
    2025/09/10 17:12:55:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/10 17:12:55:   Converting TOA radiance to TOA reflectance for SWIR detector...
    2025/09/10 17:12:55:   Starting orthorectification...
    2025/09/10 17:12:55:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257740.0, 656040.0, 5266620.0)
    2025/09/10 17:12:55:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:12:56:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:12:58:   Merging VNIR and SWIR data...
    2025/09/10 17:12:58:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:12:58:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:12:58:   Generating L2A metadata...
    2025/09/10 17:12:59:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (296, 958, 209) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.TIF.
    Writing GeoArray of size (296, 958) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (296, 958, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:13:00:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_header.xml
    2025/09/10 17:13:00:   L2A product successfully written!
    2025/09/10 17:13:00:   Total runtime of the processing chain: 0:00:08.345282

##### Captured stderr call

    2025/09/10 17:12:54:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:12:54:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:12:54:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:12:54:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:12:54:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:13:00:   The 'mask_landwater' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'mask_cloudshadow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'mask_haze' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'mask_snow' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'mask_cirrus' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/10 17:13:00:   The 'sicor_cwv' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'sicor_liq' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'sicor_ice' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:00:   No XML metadata conversion implemented for datasets different to the DLR format.Metadata XML file will be empty.

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata::test_run_all_processors 0:00:59.063048

Started | 2025-09-10 17:13:00
Ended | 2025-09-10 17:13:59
Duration | 0:00:59.063048
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 24,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': 50,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-799.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpz9wyrsyv'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'land',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spatial',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': False},
                    'geometry': {'enable_absolute_coreg': True,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/T30TXQ_20170218T110111_B05__sub.tif'},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/10 17:13:00:   Reading metadata for VNIR detector...
    2025/09/10 17:13:01:   Calculating solar irradiance...
    2025/09/10 17:13:01:   Reading metadata for SWIR detector...
    2025/09/10 17:13:01:   Calculating solar irradiance...
    2025/09/10 17:13:01:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:13:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:13:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:13:02:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:13:02:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:13:02:   Computing VNIR geolayer...
    2025/09/10 17:13:03:   Computing SWIR geolayer...
    2025/09/10 17:13:03:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/10 17:13:03:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/10 17:13:03:   Preparing reference image for co-registration.
    2025/09/10 17:13:04:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/10 17:13:15:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.16s
    2025/09/10 17:13:15:   Transforming spatial optimization results back to sensor geometry.
    2025/09/10 17:13:15:   Applying results of spatial optimization to geolayer.
    2025/09/10 17:13:15:   Pre-processing DEM for VNIR...
    2025/09/10 17:13:16:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/10 17:13:16:   Pre-processing DEM for SWIR...
    2025/09/10 17:13:16:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/10 17:13:16:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/10 17:13:16:   Starting atmospheric correction for VNIR and SWIR detector in 'land' mode. Source radiometric unit code is 'TOARad'.
    2025/09/10 17:13:16:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/10 17:13:16:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 24,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/10 17:13:16:   Setting up forward operator...
    2025/09/10 17:13:16:   SICOR is applied to land AND water pixels.
    2025/09/10 17:13:16:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/10 17:13:18:   Getting observation metadata...
    2025/09/10 17:13:18:   Checking if observation metadata values are within LUT value ranges...
    2025/09/10 17:13:18:   Loading solar irradiance model...
    2025/09/10 17:13:18:   Loading RT LUT...
    2025/09/10 17:13:18:   LUT file was properly downloaded and is available for AC!
    2025/09/10 17:13:18:   Converting LUT to Fontenla solar model...
    2025/09/10 17:13:18:   Resampling LUT to EnMAP wavelengths...
    2025/09/10 17:13:41:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/10 17:13:41:   Calculating absorption coefficients of liquid water and ice...
    2025/09/10 17:13:42:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/10 17:13:43:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/10 17:13:43:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/10 17:13:43:   Performing first guess ice retrieval based on the NDSI...
    2025/09/10 17:13:43:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/10 17:13:43:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/10 17:13:43:   Preparing segmented SWIR L1B data cube...
    2025/09/10 17:13:44:   Performing 3 phases of water retrieval...
    2025/09/10 17:13:44:   Setting up multiprocessing...
    2025/09/10 17:13:44:   Multiprocessing on 24 cpu's
    2025/09/10 17:13:44:   Preparing optimal estimation input...
    2025/09/10 17:13:44:   Optimization...
    2025/09/10 17:13:46:   Done!
    2025/09/10 17:13:46:   Runtime: 2.24 s
    2025/09/10 17:13:46:   Smoothing segmented CWV retrieval map...
    2025/09/10 17:13:46:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/10 17:13:47:   Starting surface reflectance retrieval...
    2025/09/10 17:13:47:   Calculating surface reflectance for vnir detector...
    2025/09/10 17:13:49:   Calculating surface reflectance for swir detector...
    2025/09/10 17:13:52:   Smoothing segmented liquid water and ice maps...
    2025/09/10 17:13:53:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/10 17:13:53:   Joining results of atmospheric correction.
    2025/09/10 17:13:53:   Starting orthorectification...
    2025/09/10 17:13:53:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636960.0, 4940670.0, 666090.0, 4949310.0)
    2025/09/10 17:13:53:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:13:54:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:13:55:   Merging VNIR and SWIR data...
    2025/09/10 17:13:55:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:13:55:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:13:55:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:13:55:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:13:56:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:13:56:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:13:56:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/10 17:13:56:   Orthorectifying 'sicor_liq' attribute...
    2025/09/10 17:13:57:   Orthorectifying 'sicor_ice' attribute...
    2025/09/10 17:13:57:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:13:57:   Generating L2A metadata...
    2025/09/10 17:13:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (288, 971, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (288, 971, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (288, 971) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/10 17:13:59:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/10 17:13:59:   L2A product successfully written!
    2025/09/10 17:13:59:   Total runtime of the processing chain: 0:00:58.772255

##### Captured stderr call

    2025/09/10 17:13:00:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/10 17:13:03:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.1% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.3% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.0% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.1% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.6% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.5% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.3% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.2% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.4% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.1% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.4% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.4% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.2% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.7% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.0% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.5% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.3% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.2% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.5% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.0% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.4% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.1% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.2% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.4% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.3% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.1% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.4% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.4% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.7% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.6% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.1% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.2% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.2% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.3% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.4% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.4% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.0% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.5% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.1% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.4% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.1% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.5% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.2% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.2% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.3% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:09
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:09
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:09
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:09
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:09
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:09
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:09
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:09
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:09
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:09
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:09
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:09
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:09
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:09
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:09
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:09
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:09
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:09
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:09
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:09
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:09
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:09
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:09
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:09
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:09
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:09
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:09
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:09
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:09
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:09
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:09
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:09
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:09
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:09
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:09
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:09
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:09
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:09
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:10
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:10
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:10
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:10
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:10
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:10
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:10
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:10
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:10
    	progress: |============================----------------------| 55.3% Complete  => 0:00:10
    	progress: |============================----------------------| 55.9% Complete  => 0:00:10
    	progress: |============================----------------------| 56.5% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:10
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:10
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:10
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:10
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:10
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:10
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:10
    	progress: |================================------------------| 63.4% Complete  => 0:00:10
    	progress: |================================------------------| 64.0% Complete  => 0:00:10
    	progress: |================================------------------| 64.6% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:10
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:10
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:10
    	progress: |==================================----------------| 67.1% Complete  => 0:00:10
    	progress: |==================================----------------| 67.7% Complete  => 0:00:10
    	progress: |==================================----------------| 68.3% Complete  => 0:00:10
    	progress: |==================================----------------| 68.9% Complete  => 0:00:10
    	progress: |===================================---------------| 69.6% Complete  => 0:00:10
    	progress: |===================================---------------| 70.2% Complete  => 0:00:10
    	progress: |===================================---------------| 70.8% Complete  => 0:00:10
    	progress: |====================================--------------| 71.4% Complete  => 0:00:10
    	progress: |====================================--------------| 72.0% Complete  => 0:00:10
    	progress: |====================================--------------| 72.7% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:10
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:10
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:10
    	progress: |======================================------------| 75.2% Complete  => 0:00:10
    	progress: |======================================------------| 75.8% Complete  => 0:00:10
    	progress: |======================================------------| 76.4% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:10
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:10
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:10
    	progress: |========================================----------| 79.5% Complete  => 0:00:10
    	progress: |========================================----------| 80.1% Complete  => 0:00:10
    	progress: |========================================----------| 80.7% Complete  => 0:00:10
    	progress: |=========================================---------| 81.4% Complete  => 0:00:10
    	progress: |=========================================---------| 82.0% Complete  => 0:00:10
    	progress: |=========================================---------| 82.6% Complete  => 0:00:10
    	progress: |==========================================--------| 83.2% Complete  => 0:00:10
    	progress: |==========================================--------| 83.9% Complete  => 0:00:10
    	progress: |==========================================--------| 84.5% Complete  => 0:00:10
    	progress: |===========================================-------| 85.1% Complete  => 0:00:10
    	progress: |===========================================-------| 85.7% Complete  => 0:00:10
    	progress: |===========================================-------| 86.3% Complete  => 0:00:10
    	progress: |===========================================-------| 87.0% Complete  => 0:00:10
    	progress: |============================================------| 87.6% Complete  => 0:00:10
    	progress: |============================================------| 88.2% Complete  => 0:00:10
    	progress: |============================================------| 88.8% Complete  => 0:00:10
    	progress: |=============================================-----| 89.4% Complete  => 0:00:10
    	progress: |=============================================-----| 90.1% Complete  => 0:00:10
    	progress: |=============================================-----| 90.7% Complete  => 0:00:10
    	progress: |==============================================----| 91.3% Complete  => 0:00:10
    	progress: |==============================================----| 91.9% Complete  => 0:00:10
    	progress: |==============================================----| 92.5% Complete  => 0:00:10
    	progress: |===============================================---| 93.2% Complete  => 0:00:10
    	progress: |===============================================---| 93.8% Complete  => 0:00:10
    	progress: |===============================================---| 94.4% Complete  => 0:00:10
    	progress: |================================================--| 95.0% Complete  => 0:00:10
    	progress: |================================================--| 95.7% Complete  => 0:00:10
    	progress: |================================================--| 96.3% Complete  => 0:00:10
    	progress: |================================================--| 96.9% Complete  => 0:00:10
    	progress: |=================================================-| 97.5% Complete  => 0:00:10
    	progress: |=================================================-| 98.1% Complete  => 0:00:10
    	progress: |=================================================-| 98.8% Complete  => 0:00:10
    	progress: |==================================================| 99.4% Complete  => 0:00:10
    	progress: |==================================================| 100.0% Complete  => 0:00:10

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.3% Complete  => 0:00:00
    	progress: |=-------------------------------------------------| 1.8% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.6% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 5.3% Complete  => 0:00:00
    	progress: |====----------------------------------------------| 8.0% Complete  => 0:00:00
    	progress: |==========----------------------------------------| 20.0% Complete  => 0:00:00
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:00
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:00
    	progress: |==========================------------------------| 51.1% Complete  => 0:00:01
    	progress: |===================================---------------| 70.7% Complete  => 0:00:01
    	progress: |==========================================--------| 83.6% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/10 17:13:52:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:13:53:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:13:58:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/10 17:13:59:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:59:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:13:59:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_import_polymer 0:00:00.038844

Started | 2025-09-10 17:13:59
Ended | 2025-09-10 17:13:59
Duration | 0:00:00.038844
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors 0:01:22.841907

Started | 2025-09-10 17:13:59
Ended | 2025-09-10 17:15:22
Duration | 0:01:22.841907
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmpasg5f1my'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/10 17:13:59:   Reading metadata for VNIR detector...
    2025/09/10 17:13:59:   Calculating solar irradiance...
    2025/09/10 17:14:00:   Reading metadata for SWIR detector...
    2025/09/10 17:14:00:   Calculating solar irradiance...
    2025/09/10 17:14:00:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:14:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:14:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:14:00:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:14:00:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:14:00:   Computing VNIR geolayer...
    2025/09/10 17:14:01:   Computing SWIR geolayer...
    2025/09/10 17:14:01:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:14:01:   Percentage of defective pixels: 0.49
    2025/09/10 17:14:01:   Percentage of pixels with a defect in any band: 35.60
    2025/09/10 17:14:01:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:14:01:   Percentage of defective pixels: 0.50
    2025/09/10 17:14:01:   Percentage of pixels with a defect in any band: 44.50
    2025/09/10 17:14:01:   Pre-processing DEM for VNIR...
    2025/09/10 17:14:01:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/10 17:14:01:   Pre-processing DEM for SWIR...
    2025/09/10 17:14:01:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/10 17:14:01:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/10 17:14:01:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/10 17:14:01:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': True,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/10 17:14:01:   Setting up forward operator...
    2025/09/10 17:14:02:   SICOR is applied to land pixels only. This may result in edge effects, e.g., at coastlines...
    2025/09/10 17:14:02:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/10 17:14:03:   Getting observation metadata...
    2025/09/10 17:14:03:   Checking if observation metadata values are within LUT value ranges...
    2025/09/10 17:14:03:   Loading solar irradiance model...
    2025/09/10 17:14:03:   Loading RT LUT...
    2025/09/10 17:14:03:   LUT file was properly downloaded and is available for AC!
    2025/09/10 17:14:03:   Converting LUT to Fontenla solar model...
    2025/09/10 17:14:03:   Resampling LUT to EnMAP wavelengths...
    2025/09/10 17:14:23:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/10 17:14:24:   Calculating absorption coefficients of liquid water and ice...
    2025/09/10 17:14:24:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/10 17:14:25:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/10 17:14:25:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/10 17:14:25:   Performing first guess ice retrieval based on the NDSI...
    2025/09/10 17:14:25:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/10 17:14:25:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/10 17:14:25:   Preparing segmented SWIR L1B data cube...
    2025/09/10 17:14:26:   Performing 3 phases of water retrieval...
    2025/09/10 17:14:26:   Setting up multiprocessing...
    2025/09/10 17:14:26:   Multiprocessing on 16 cpu's
    2025/09/10 17:14:26:   Preparing optimal estimation input...
    2025/09/10 17:14:26:   Optimization...
    2025/09/10 17:14:27:   Done!
    2025/09/10 17:14:27:   Runtime: 1.44 s
    2025/09/10 17:14:27:   Smoothing segmented CWV retrieval map...
    2025/09/10 17:14:27:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/10 17:14:27:   Starting surface reflectance retrieval...
    2025/09/10 17:14:27:   Calculating surface reflectance for vnir detector...
    2025/09/10 17:14:29:   Calculating surface reflectance for swir detector...
    2025/09/10 17:14:30:   Smoothing segmented liquid water and ice maps...
    2025/09/10 17:14:31:   SICOR atmospheric correction for EnMAP in combined mode successfully finished!
    vnir
    2025/09/10 17:14:31:   Running polymer...
    Initializing ENMAP product of size (30, 1000)
    2025/09/10 17:14:31:   Landmask is EnMAP L1B
    Starting processing at 2025-09-10 17:14:31.330946
    Processing block: size (30, 1000), offset (0, 0)
    Done in 0:00:45.961866
    2025/09/10 17:15:17:   Joining results of atmospheric correction.
    2025/09/10 17:15:17:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/10 17:15:17:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:17:   Percentage of defective pixels: 0.49
    2025/09/10 17:15:17:   Percentage of pixels with a defect in any band: 35.60
    2025/09/10 17:15:17:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:17:   Percentage of defective pixels: 0.50
    2025/09/10 17:15:17:   Percentage of pixels with a defect in any band: 44.50
    2025/09/10 17:15:17:   Starting orthorectification...
    2025/09/10 17:15:17:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/10 17:15:17:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:15:18:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:15:18:   Merging VNIR and SWIR data...
    2025/09/10 17:15:18:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:15:18:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'sicor_liq' attribute...
    2025/09/10 17:15:19:   Orthorectifying 'sicor_ice' attribute...
    2025/09/10 17:15:20:   Orthorectifying 'polymer_logchl' attribute...
    2025/09/10 17:15:20:   Orthorectifying 'polymer_logfb' attribute...
    2025/09/10 17:15:20:   Orthorectifying 'polymer_rgli' attribute...
    2025/09/10 17:15:20:   Orthorectifying 'polymer_rnir' attribute...
    2025/09/10 17:15:20:   Orthorectifying 'polymer_bitmask' attribute...
    2025/09/10 17:15:20:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:15:21:   Generating L2A metadata...
    2025/09/10 17:15:21:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGCHL.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_LOGFB.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RGLI.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_RNIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_POLYMER_BITMASK.TIF.
    2025/09/10 17:15:22:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/10 17:15:22:   L2A product successfully written!
    2025/09/10 17:15:22:   Total runtime of the processing chain: 0:01:22.773881

##### Captured stderr call

    2025/09/10 17:13:59:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |=====---------------------------------------------| 9.8% Complete  => 0:00:00
    	progress: |===========---------------------------------------| 22.0% Complete  => 0:00:00
    	progress: |========================--------------------------| 48.8% Complete  => 0:00:00
    	progress: |==================================================| 100.0% Complete  => 0:00:00
    2025/09/10 17:14:31:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:14:31:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:15:22:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/10 17:15:22:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:15:22:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:15:22:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

### PASSED Test_EnPT_Controller_DLR_testdata_ACWater::test_run_all_processors_without_acwater_installed 0:00:39.137050

Test to run all processors while replacing polymer_ac_enmap with None using mock.patch.

Started | 2025-09-10 17:15:22
Ended | 2025-09-10 17:16:01
Duration | 0:00:39.137050
Markers | skipif False reason='POLYMER is not installed.'
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    EnPT Controller received the following configuration:
    {'general_opts': {'CPUs': 16,
                      'average_elevation': 0,
                      'create_logfile': True,
                      'disable_progress_bars': False,
                      'drop_bad_bands': True,
                      'is_dummy_dataformat': False,
                      'log_level': 'DEBUG',
                      'n_lines_to_append': None,
                      'path_dem': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER.bsq',
                      'path_l1b_enmap_image': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/EnMAP_Level_1B/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__rows700-730.zip',
                      'path_l1b_enmap_image_gapfill': '',
                      'path_l1b_snr_model': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/EnMAP_Sensor/EnMAP_Level_1B_SNR.zip',
                      'working_dir': '/tmp/tmppzbry6y3'},
     'output': {'output_dir': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/../tests/data/test_outputs',
                'output_format': 'GTiff',
                'output_interleave': 'pixel',
                'output_nodata_value': -32768},
     'processors': {'atmospheric_correction': {'auto_download_ecmwf': True,
                                               'blocksize': 100,
                                               'enable_ac': True,
                                               'enable_segmentation': True,
                                               'isofit_surface_category': 'multicomponent_surface',
                                               'land_ac_alg': 'SICOR',
                                               'mode_ac': 'combined',
                                               'path_isofit_surface_config': '',
                                               'path_isofit_surface_priors': '',
                                               'polymer_additional_results': True,
                                               'polymer_root': '/root/polymer-v4.16.1',
                                               'scale_factor_boa_ref': 10000,
                                               'threads': -1},
                    'dead_pixel': {'algorithm': 'spectral',
                                   'interp_method_spatial': 'linear',
                                   'interp_method_spectral': 'linear',
                                   'run_processor': True},
                    'geometry': {'enable_absolute_coreg': False,
                                 'enable_keystone_correction': False,
                                 'enable_vnir_swir_coreg': False,
                                 'path_reference_image': ''},
                    'orthorectification': {'resamp_alg': 'bilinear',
                                           'target_coord_grid': {'x': array([ 0, 30]),
                                                                 'y': array([ 0, 30])},
                                           'target_epsg': None,
                                           'target_projection_type': 'UTM',
                                           'vswir_overlap_algorithm': 'swir_only'},
                    'smile': {'run_processor': False},
                    'toa_ref': {'path_earthSunDist': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/earth_sun_distance/Earth_Sun_distances_per_day_edited__1980_2030.csv',
                                'path_solar_irr': '/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/enpt/resources/solar_irradiance/SUNp1fontenla__350-2500nm_@0.1nm_converted.txt',
                                'scale_factor_toa_ref': 10000}}}
    2025/09/10 17:15:22:   Reading metadata for VNIR detector...
    2025/09/10 17:15:22:   Calculating solar irradiance...
    2025/09/10 17:15:22:   Reading metadata for SWIR detector...
    2025/09/10 17:15:23:   Calculating solar irradiance...
    2025/09/10 17:15:23:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:15:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:15:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:15:23:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:15:23:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:15:23:   Computing VNIR geolayer...
    2025/09/10 17:15:23:   Computing SWIR geolayer...
    2025/09/10 17:15:24:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:24:   Percentage of defective pixels: 0.49
    2025/09/10 17:15:24:   Percentage of pixels with a defect in any band: 35.60
    2025/09/10 17:15:24:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:24:   Percentage of defective pixels: 0.50
    2025/09/10 17:15:24:   Percentage of pixels with a defect in any band: 44.50
    2025/09/10 17:15:24:   Pre-processing DEM for VNIR...
    2025/09/10 17:15:24:   Transforming DEM to VNIR sensor geometry (using first band of VNIR geolayer)...
    2025/09/10 17:15:24:   Pre-processing DEM for SWIR...
    2025/09/10 17:15:24:   Transforming DEM to SWIR sensor geometry (using first band of SWIR geolayer)...
    2025/09/10 17:15:24:   Transforming the 'mask_landwater' attribute from VNIR to SWIR sensor geometry.
    2025/09/10 17:15:24:   Starting atmospheric correction for VNIR and SWIR detector in 'combined' mode. Source radiometric unit code is 'TOARad'.
    2025/09/10 17:15:24:   Running atmospheric correction in 'land' mode, i.e., SICOR is applied to ALL surfaces. Uncertainty is expected for water surfaces because SICOR is designed for land only.
    2025/09/10 17:15:24:   SICOR AC configuration:
    {'processing': {'Exception': None,
                    'Exception_type': '',
                    'clear_fraction': None,
                    'interface': {'args': (), 'kwargs': {}},
                    'status': 1,
                    'tIO': 0.0,
                    'tRT': 0.0,
                    'uncertainties': {}},
     'retrieval': {'cpu': 16,
                   'default_aot_value': 0.192,
                   'disable_progressbars': False,
                   'fn_LUT': '',
                   'inversion': {'eps': 0.01,
                                 'full': False,
                                 'gnform': 'n',
                                 'maxiter': 35},
                   'land_only': False,
                   'n_pca': 5,
                   'segmentation': True,
                   'segs': 200,
                   'smoothing_sigma': 50,
                   'sol_model': 'fontenla',
                   'state_vector': {'ice': {'ll': 0.001,
                                            'prior_mean': 0.02,
                                            'prior_sigma': 1000.0,
                                            'ul': 0.499,
                                            'use_prior_mean': False},
                                    'intercept': {'ll': 0.001,
                                                  'prior_mean': 0.3,
                                                  'prior_sigma': 1000.0,
                                                  'ul': 0.999,
                                                  'use_prior_mean': False},
                                    'liquid_water': {'ll': 0.001,
                                                     'prior_mean': 0.02,
                                                     'prior_sigma': 1000.0,
                                                     'ul': 0.499,
                                                     'use_prior_mean': False},
                                    'slope': {'ll': -0.0004,
                                              'prior_mean': 0.0002,
                                              'prior_sigma': 1000.0,
                                              'ul': 0.0004,
                                              'use_prior_mean': False},
                                    'water_vapor': {'ll': 0.001,
                                                    'prior_mean': 2.5,
                                                    'prior_sigma': 1000.0,
                                                    'ul': 4.999,
                                                    'use_prior_mean': False}},
                   'unknowns': {'ice_absorption_coefficients': {'sigma': 2.39e-07},
                                'liquid_water_absorption_coefficients': {'sigma': 2.43e-07},
                                'skyview': {'sigma': 0.1},
                                'water_vapor_absorption_coefficients': {'sigma': 0.01}}},
     'sensor': {'fit': {'idx': [14,
                                15,
                                16,
                                17,
                                18,
                                19,
                                20,
                                21,
                                22,
                                23,
                                24,
                                25,
                                26,
                                27,
                                28,
                                29,
                                30,
                                31],
                        'snr': [322.94254006,
                                313.45752342,
                                313.32464722,
                                306.19455173,
                                281.35641378,
                                227.9759974,
                                157.22390595,
                                148.93620623,
                                154.40197388,
                                182.60431866,
                                232.89644996,
                                250.1244036,
                                252.2267179,
                                272.16592448,
                                299.71964816,
                                316.11909184,
                                326.33202741,
                                312.28461288]},
                'name': 'EnMAP',
                'resamp_alg': 'nearest'}}
    2025/09/10 17:15:24:   Setting up forward operator...
    2025/09/10 17:15:24:   SICOR is applied to land AND water pixels.
    2025/09/10 17:15:24:   Transforming VNIR data to SWIR sensor geometry to enable first guess retrievals for liquid water and ice...
    2025/09/10 17:15:25:   Getting observation metadata...
    2025/09/10 17:15:25:   Checking if observation metadata values are within LUT value ranges...
    2025/09/10 17:15:25:   Loading solar irradiance model...
    2025/09/10 17:15:25:   Loading RT LUT...
    2025/09/10 17:15:25:   LUT file was properly downloaded and is available for AC!
    2025/09/10 17:15:25:   Converting LUT to Fontenla solar model...
    2025/09/10 17:15:26:   Resampling LUT to EnMAP wavelengths...
    2025/09/10 17:15:48:   Reducing grid dimensionality of LUT to increase interpolation speed...
    2025/09/10 17:15:49:   Calculating absorption coefficients of liquid water and ice...
    2025/09/10 17:15:49:   Performing first guess water vapor retrieval based on a common band ratio using VNIR data...
    2025/09/10 17:15:50:   Transforming CWV first guess map to SWIR sensor geometry to enable segmentation and 3 phases of water retrieval...
    2025/09/10 17:15:50:   Performing first guess liquid water retrieval based on the NDWI...
    2025/09/10 17:15:50:   Performing first guess ice retrieval based on the NDSI...
    2025/09/10 17:15:50:   Calculating first guess for intercept and slope of absorption feature continuum...
    2025/09/10 17:15:50:   Segmenting SWIR L1B spectra to enhance processing speed...
    2025/09/10 17:15:50:   Preparing segmented SWIR L1B data cube...
    2025/09/10 17:15:51:   Performing 3 phases of water retrieval...
    2025/09/10 17:15:51:   Setting up multiprocessing...
    2025/09/10 17:15:51:   Multiprocessing on 16 cpu's
    2025/09/10 17:15:51:   Preparing optimal estimation input...
    2025/09/10 17:15:51:   Optimization...
    2025/09/10 17:15:53:   Done!
    2025/09/10 17:15:53:   Runtime: 2.15 s
    2025/09/10 17:15:53:   Smoothing segmented CWV retrieval map...
    2025/09/10 17:15:53:   Transforming smoothed CWV retrieval map to VNIR sensor geometry to enable AC of VNIR data...
    2025/09/10 17:15:53:   Starting surface reflectance retrieval...
    2025/09/10 17:15:53:   Calculating surface reflectance for vnir detector...
    2025/09/10 17:15:55:   Calculating surface reflectance for swir detector...
    2025/09/10 17:15:57:   Smoothing segmented liquid water and ice maps...
    2025/09/10 17:15:57:   SICOR atmospheric correction for EnMAP in land mode successfully finished!
    2025/09/10 17:15:57:   Joining results of atmospheric correction.
    2025/09/10 17:15:57:   Re-applying dead pixel correction to correct for spectral spikes due to fringe effect.
    2025/09/10 17:15:57:   Correcting dead pixels of VNIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:57:   Percentage of defective pixels: 0.49
    2025/09/10 17:15:57:   Percentage of pixels with a defect in any band: 35.60
    2025/09/10 17:15:57:   Correcting dead pixels of SWIR detector...
    Used algorithm: linear interpolation in the spectral domain
    2025/09/10 17:15:57:   Percentage of defective pixels: 0.50
    2025/09/10 17:15:57:   Percentage of pixels with a defect in any band: 44.50
    2025/09/10 17:15:57:   Starting orthorectification...
    2025/09/10 17:15:57:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (637410.0, 4942680.0, 666180.0, 4949340.0)
    2025/09/10 17:15:57:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:15:58:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:15:58:   Merging VNIR and SWIR data...
    2025/09/10 17:15:58:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:15:58:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'sicor_cwv' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'sicor_liq' attribute...
    2025/09/10 17:15:59:   Orthorectifying 'sicor_ice' attribute...
    2025/09/10 17:16:00:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:16:00:   Generating L2A metadata...
    2025/09/10 17:16:01:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (222, 959, 202) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.TIF.
    Writing GeoArray of size (222, 959, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_CWV.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_LIQ.TIF.
    Writing GeoArray of size (222, 959) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-ACOUT_SICOR_ICE.TIF.
    2025/09/10 17:16:01:   Writing metadata to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-METADATA.XML
    2025/09/10 17:16:01:   L2A product successfully written!
    2025/09/10 17:16:01:   Total runtime of the processing chain: 0:00:39.085891

##### Captured stderr call

    2025/09/10 17:15:22:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/10 17:15:24:   Polymer is not callable. As a fallback, SICOR is applied to water surfaces instead.

    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |--------------------------------------------------| 0.0% Complete  => 0:00:00
    	progress: |==------------------------------------------------| 3.6% Complete  => 0:00:00
    	progress: |===-----------------------------------------------| 6.0% Complete  => 0:00:00
    	progress: |=======-------------------------------------------| 13.9% Complete  => 0:00:00
    	progress: |========------------------------------------------| 15.7% Complete  => 0:00:00
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:00
    	progress: |===============-----------------------------------| 30.7% Complete  => 0:00:00
    	progress: |=========================-------------------------| 49.4% Complete  => 0:00:00
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:01
    	progress: |=================================-----------------| 65.1% Complete  => 0:00:01
    	progress: |=====================================-------------| 74.7% Complete  => 0:00:01
    	progress: |================================================--| 95.2% Complete  => 0:00:01
    	progress: |==================================================| 100.0% Complete  => 0:00:01
    2025/09/10 17:15:57:   VNIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:15:57:   SWIR L2A data contain negative values indicating an overcorrection. Please check for errors in the input data, the options file, or the processing code.
    2025/09/10 17:16:01:   Currently, L2A dead pixel masks cannot be saved yet.
    2025/09/10 17:16:01:   The 'isofit_atm_state' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'isofit_uncertainty' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'polymer_logchl' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'polymer_logfb' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'polymer_rgli' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'polymer_rnir' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   The 'polymer_bitmask' attribute cannot be saved because it does not exist in the current EnMAP image.
    2025/09/10 17:16:01:   Currently, the L2A metadata XML file does not contain all relevant keys and contains not updated values!

#### Teardown

## tests/test_dead_pixel_correction.py 15 0:00:08.363814

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spatial 0:00:03.974770

Started | 2025-09-10 17:16:01
Ended | 2025-09-10 17:16:05
Duration | 0:00:03.974770
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_2D_deadpixelmap_spectral 0:00:00.100592

Started | 2025-09-10 17:16:05
Ended | 2025-09-10 17:16:05
Duration | 0:00:00.100592
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spatial 0:00:04.044623

Started | 2025-09-10 17:16:05
Ended | 2025-09-10 17:16:09
Duration | 0:00:04.044623
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_Dead_Pixel_Corrector::test_correct_using_3D_deadpixelmap_spectral 0:00:00.172703

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.172703
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_0 0:00:00.003122

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.003122
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_axis_1 0:00:00.002690

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.002690
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis_2d::test_bad_args 0:00:00.001226

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.001226
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_2d 0:00:00.002021

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.002021
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_0 0:00:00.002822

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.002822
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_1 0:00:00.003541

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.003541
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_3d_axis_2 0:00:00.041849

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.041849
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_along_axis::test_bad_args 0:00:00.000998

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.000998
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_bad_args 0:00:00.001179

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.001179
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_pandas 0:00:00.004667

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.004667
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_interp_nodata_spatially_2d::test_interpolation_scipy 0:00:00.007012

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.007012
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_dem_preprocessing.py 8 0:00:00.405210

### PASSED Test_DEM_Processor::test_compute_aspect 0:00:00.074693

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:09
Duration | 0:00:00.074693
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_compute_slopes 0:00:00.024047

Started | 2025-09-10 17:16:09
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.024047
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_fill_gaps 0:00:00.023536

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.023536
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_get_flat_dem 0:00:00.033748

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.033748
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_demTooSmall 0:00:00.032970

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.032970
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_noWGS84 0:00:00.024121

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.024121
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_init_nomapinfo 0:00:00.022513

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.022513
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_DEM_Processor::test_to_sensor_geometry 0:00:00.169582

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:10
Duration | 0:00:00.169582
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_images_sensorgeo.py 6 0:00:23.330900

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr 0:00:02.353915

Started | 2025-09-10 17:16:10
Ended | 2025-09-10 17:16:12
Duration | 0:00:02.353915
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/10 17:16:10:   Reading metadata for VNIR detector...
    2025/09/10 17:16:10:   Calculating solar irradiance...
    2025/09/10 17:16:10:   Reading metadata for SWIR detector...
    2025/09/10 17:16:11:   Calculating solar irradiance...
    2025/09/10 17:16:11:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:16:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:16:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:16:11:   Computing VNIR geolayer...
    2025/09/10 17:16:12:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/10 17:16:10:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

#### Call

##### Captured stdout call

    2025/09/10 17:16:12:   Transforming the 'mask_snow' attribute from VNIR to SWIR sensor geometry.

##### Captured stderr call

    2025/09/10 17:16:12:   The mask_snow is not yet available in SWIR sensor geometry. Use EnMAP_SWIR_SensorGeo.transform_vnir_to_swir_raster() to set it with a transformed version of the one provided in VNIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_set_SWIRattr_with_transformedVNIRattr__attrIsNone 0:00:00.007369

Started | 2025-09-10 17:16:12
Ended | 2025-09-10 17:16:12
Duration | 0:00:00.007369
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:16:12:   Transforming the 'mask_haze' attribute from VNIR to SWIR sensor geometry.

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster__no_geolayer 0:00:00.010163

Started | 2025-09-10 17:16:12
Ended | 2025-09-10 17:16:12
Duration | 0:00:00.010163
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_swir_to_vnir_raster_no_keystone 0:00:01.985223

Started | 2025-09-10 17:16:12
Ended | 2025-09-10 17:16:14
Duration | 0:00:01.985223
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster__no_geolayer 0:00:00.001290

Started | 2025-09-10 17:16:14
Ended | 2025-09-10 17:16:14
Duration | 0:00:00.001290
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_EnMAPL1Product_SensorGeo::test_transform_vnir_to_swir_raster_with_keystone 0:00:18.972939

Started | 2025-09-10 17:16:14
Ended | 2025-09-10 17:16:33
Duration | 0:00:18.972939
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_isofit_enmap.py 65 0:02:05.706377

### PASSED Test_ISOFIT_EnMAP::test__compute_cos_i 0:00:10.041940

Started | 2025-09-10 17:16:33
Ended | 2025-09-10 17:16:43
Duration | 0:00:10.041940
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:16:33:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/10 17:16:33:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/10 17:16:34:   LUT zipfile already downloaded. Proceeding.
    2025/09/10 17:16:34:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Pulling release v1.0.3
    Downloading file
    Unzipping /root/.isofit/isofit-data.zip
    Done, now available at: /root/.isofit/data
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Pulling release v1.2.10
    Downloading file
    Unzipping /root/.isofit/isofit-tutorials.zip
    Downloading NEON data for the example
    Output as: /root/.isofit/examples/isotuts/NEON/data
    Downloading file
    Unzipping /root/.isofit/examples/isotuts/NEON/NEON-subset-data.zip
    Done, now available at: /root/.isofit/examples
    [!] Be sure to build the examples for your system via `isofit build`

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__compute_solar_phase 0:00:00.289890

Started | 2025-09-10 17:16:43
Ended | 2025-09-10 17:16:44
Duration | 0:00:00.289890
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:16:43:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/10 17:16:43:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/10 17:16:44:   LUT zipfile already downloaded. Proceeding.
    2025/09/10 17:16:44:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_6s 0:00:00.000784

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-10 17:16:44
Ended | 2025-09-10 17:16:44
Duration | 0:00:00.000784
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 185, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test__run__backtransformed_l2_spectra_lut_mod5 0:01:17.367836

4x3 spectra within 10x10 image. Lines: different forward sim.: #1: UVEG LUT; #2: Luis LUT, #3: MODTRAN.

Started | 2025-09-10 17:16:44
Ended | 2025-09-10 17:18:01
Duration | 0:01:17.367836
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:16:44:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/10 17:16:44:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/10 17:16:44:   LUT zipfile already downloaded. Proceeding.
    2025/09/10 17:16:44:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/10 17:16:44:   Generating LUT file...
    2025/09/10 17:16:54:   Flightline ID: 20220717T110603Z
    2025/09/10 17:16:54:   no noise path found, proceeding without
    2025/09/10 17:16:54:   Running ISOFIT...
    2025/09/10 17:16:54:   Loading config file: /tmp/tmp29q1jo42/workdir/config/isofit_config.json
    2025/09/10 17:16:54:   Checking config sections for configuration issues
    2025/09/10 17:16:54:   Configuration file checks complete, no errors found.
    2025/09/10 17:17:03:   Building first forward model, will generate any necessary LUTs
    2025/09/10 17:17:03:   Loading from wavelength_file: /tmp/tmp29q1jo42/extracted/backtransformed_l2_spectra_v9/enmap_wavelengths.txt
    2025/09/10 17:17:03:   Prebuilt LUT provided
    2025/09/10 17:17:14:   Loading LUT into memory
    2025/09/10 17:17:15:   LUT grid loaded from file: OrderedDict({'AERFRAC_2': [0.05, 0.12, 0.2, 0.3, 0.4, 0.8], 'H2OSTR': [0.0, 1.0, 1.5, 2.0, 2.7, 3.5, 5.0], 'observer_zenith': [0, 10.0, 20.0, 30.0, 40.0], 'relative_azimuth': [0, 25.0, 50.0, 85.0, 120.0, 155.0, 180.0], 'solar_zenith': [0, 10.0, 20.0, 35.0, 50.0, 70.0], 'surface_elevation_km': [0, 0.7, 2.5, 8.0]})
    2025/09/10 17:17:44:   Beginning 100 inversions in 100 chunks using 20 cores
    2025/09/10 17:17:59:   Inversions complete.  14.78s total, 6.7661 spectra/s, 0.3383 spectra/s/core
    2025/09/10 17:17:59:   ISOFIT finished.
    2025/09/10 17:17:59:   Stopping ray.

##### Captured stderr call

    2025/09/10 17:16:54:
    ******************************************************************************************
    ! Number of threads is greater than 1 (currently: 24), this may greatly impact performance
    ! Please set this the environment variables 'MKL_NUM_THREADS' and 'OMP_NUM_THREADS' to '1'
    ******************************************************************************************
    2025-09-10 17:16:59,110	WARNING services.py:2070 -- WARNING: The object store is using /tmp instead of /dev/shm because /dev/shm has only 66887680 bytes available. This will harm performance! You may be able to free up space by deleting files in /dev/shm. If you are inside a Docker container, you can increase /dev/shm size by passing '--shm-size=10.24gb' to 'docker run' (or add it to the run_options list in a Ray cluster config). Make sure to set this to more than 30% of available RAM.
    2025-09-10 17:17:00,362	INFO worker.py:1852 -- Started a local Ray instance.
    WARNING: All log messages before absl::InitializeLog() is called are written to STDERR
    I0000 00:00:1757524679.934242     867 chttp2_transport.cc:1182] ipv4:172.17.0.13:55543: Got goaway [2] err=UNAVAILABLE:GOAWAY received; Error code: 2; Debug Text: Cancelling all calls {created_time:"2025-09-10T17:17:59.934227669+00:00", http2_error:2, grpc_status:14}

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe__direct_call 0:00:00.000766

Started | 2025-09-10 17:18:01
Ended | 2025-09-10 17:18:01
Duration | 0:00:00.000766
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 120, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_apply_oe_on_map_geometry 0:00:00.000472

Started | 2025-09-10 17:18:01
Ended | 2025-09-10 17:18:01
Duration | 0:00:00.000472
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 154, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_download_isofit_resources 0:00:02.356259

Started | 2025-09-10 17:18:01
Ended | 2025-09-10 17:18:03
Duration | 0:00:02.356259
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:18:01:   ISOFIT surface spectra zipfile successfully downloaded.
    2025/09/10 17:18:03:   LUT zipfile successfully downloaded.
    2025/09/10 17:18:03:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/10 17:18:03:   LUT zipfile already downloaded. Proceeding.

##### Captured log call

    INFO     test_downloads:_isofit_downloads.py:83 ISOFIT surface spectra zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:83 LUT zipfile successfully downloaded.
    INFO     test_downloads:_isofit_downloads.py:87 ISOFIT surface spectra zipfile already downloaded. Proceeding.
    INFO     test_downloads:_isofit_downloads.py:87 LUT zipfile already downloaded. Proceeding.

#### Teardown

### PASSED Test_ISOFIT_EnMAP::test_generate_input_files 0:00:22.565827

Started | 2025-09-10 17:18:03
Ended | 2025-09-10 17:18:26
Duration | 0:00:22.565827
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:18:03:   Downloading EnPT-internal resources for ISOFIT...
    2025/09/10 17:18:03:   ISOFIT surface spectra zipfile already downloaded. Proceeding.
    2025/09/10 17:18:04:   LUT zipfile already downloaded. Proceeding.
    2025/09/10 17:18:04:   Downloading ISOFIT extra-files...
    Downloading ISOFIT data
    Output as: /root/.isofit/data
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    Downloading ISOFIT examples
    Output as: /root/.isofit/examples
    Path already exists, please remove it or set the overwrite flag if you would like to redownload
    2025/09/10 17:18:04:   Reading Input Data
    2025/09/10 17:18:04:   Reading metadata for VNIR detector...
    2025/09/10 17:18:04:   Calculating solar irradiance...
    2025/09/10 17:18:04:   Reading metadata for SWIR detector...
    2025/09/10 17:18:04:   Calculating solar irradiance...
    2025/09/10 17:18:04:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:05:   Computing VNIR geolayer...
    2025/09/10 17:18:05:   Computing SWIR geolayer...
    2025/09/10 17:18:05:   Starting orthorectification...
    2025/09/10 17:18:05:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/10 17:18:05:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:18:06:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:18:08:   Merging VNIR and SWIR data...
    2025/09/10 17:18:08:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:18:08:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:18:08:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:18:09:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:18:09:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:18:09:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:18:09:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:18:10:   Generating L2A metadata...
    2025/09/10 17:18:11:   Generating radiance file...
    Writing GeoArray of size (290, 973, 202) to /tmp/tmp059obedh/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_rdn.
    2025/09/10 17:18:12:   Generating location file...
    2025/09/10 17:18:12:   Pre-processing DEM in map geometry...
    Automatically detected nodata value for GeoArray 'ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z__tile2__DEM_ASTER': 0.0
    Writing GeoArray of size (290, 973, 3) to /tmp/tmp059obedh/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_loc.
    2025/09/10 17:18:12:   Generating observation file...
    Writing GeoArray of size (290, 973, 11) to /tmp/tmp059obedh/ENMAP01-____L2A-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z_obs.
    2025/09/10 17:18:12:   Generating wavelength file...
    2025/09/10 17:18:12:   Generating surface file for default set of surface coverage types...
    0 ['filtered_other']
    0 ['filtered_veg']
    0 ['filtered_ocean']
    0 ['surface_Liquids']
    1 ['surface_Liquids']
    2025/09/10 17:18:15:   Generating LUT file...

##### Captured stderr call

    2025/09/10 17:18:04:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.7% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.1% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.1% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.1% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.0% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.1% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.2% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.0% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.0% Complete  => 0:00:00
    Warping progress     |============================================------| 87.1% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.1% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.2% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.0% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.0% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")
    /opt/conda/envs/ci_env/lib/python3.12/site-packages/coverage/control.py:907: CoverageWarning: No data was collected. (no-data-collected)
      self._warn("No data was collected.", slug="no-data-collected")

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry 0:00:00.000772

Started | 2025-09-10 17:18:26
Ended | 2025-09-10 17:18:26
Duration | 0:00:00.000772
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 213, 'Skipped: too slow for running in CI')

#### Teardown

### SKIPPED Test_ISOFIT_EnMAP::test_run_on_map_geometry_no_segmentation 0:00:00.000707

Started | 2025-09-10 17:18:26
Ended | 2025-09-10 17:18:26
Duration | 0:00:00.000707
Markers | skip reason='too slow for running in CI'
Fixtures | request

    Skipped: too slow for running in CI

#### Setup

    ('/builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/test_isofit_enmap.py', 217, 'Skipped: too slow for running in CI')

#### Teardown

### PASSED Test_LUTTransformer::test_modtran_lut_to_netcdf 0:00:13.081123

Started | 2025-09-10 17:18:26
Ended | 2025-09-10 17:18:39
Duration | 0:00:13.081123
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_l1b_reader.py 10 0:01:47.542429

### PASSED Test_L1B_Reader::test_append_100_lines 0:00:16.423869

Started | 2025-09-10 17:18:39
Ended | 2025-09-10 17:18:55
Duration | 0:00:16.423869
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:18:40:   Reading Input Data
    2025/09/10 17:18:40:   Reading metadata for VNIR detector...
    2025/09/10 17:18:40:   Calculating solar irradiance...
    2025/09/10 17:18:40:   Reading metadata for SWIR detector...
    2025/09/10 17:18:40:   Calculating solar irradiance...
    2025/09/10 17:18:40:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:40:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:40:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:40:   Reading metadata for VNIR detector...
    2025/09/10 17:18:41:   Calculating solar irradiance...
    2025/09/10 17:18:41:   Reading metadata for SWIR detector...
    2025/09/10 17:18:41:   Calculating solar irradiance...
    2025/09/10 17:18:41:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:41:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:41:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:41:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:41:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:41:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpb1y_gnjh/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:18:42:   L1B product successfully written!
    2025/09/10 17:18:42:   Reading Input Data
    2025/09/10 17:18:42:   Reading metadata for VNIR detector...
    2025/09/10 17:18:42:   Calculating solar irradiance...
    2025/09/10 17:18:42:   Reading metadata for SWIR detector...
    2025/09/10 17:18:42:   Calculating solar irradiance...
    2025/09/10 17:18:42:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:42:   Reading Input Data
    2025/09/10 17:18:43:   Reading metadata for VNIR detector...
    2025/09/10 17:18:43:   Calculating solar irradiance...
    2025/09/10 17:18:43:   Reading metadata for SWIR detector...
    2025/09/10 17:18:43:   Calculating solar irradiance...
    2025/09/10 17:18:43:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:43:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:43:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:43:   Reading metadata for VNIR detector...
    2025/09/10 17:18:43:   Calculating solar irradiance...
    2025/09/10 17:18:44:   Reading metadata for SWIR detector...
    2025/09/10 17:18:44:   Calculating solar irradiance...
    2025/09/10 17:18:44:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:44:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:44:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:44:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:44:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:44:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:44:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:44:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:18:46:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:18:46:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp6he08l5w/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:18:46:   L1B product successfully written!
    2025/09/10 17:18:46:   Reading Input Data
    2025/09/10 17:18:46:   Reading metadata for VNIR detector...
    2025/09/10 17:18:47:   Calculating solar irradiance...
    2025/09/10 17:18:47:   Reading metadata for SWIR detector...
    2025/09/10 17:18:47:   Calculating solar irradiance...
    2025/09/10 17:18:47:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:47:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:18:48:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:18:49:   Reading Input Data
    2025/09/10 17:18:49:   Reading metadata for VNIR detector...
    2025/09/10 17:18:49:   Calculating solar irradiance...
    2025/09/10 17:18:49:   Reading metadata for SWIR detector...
    2025/09/10 17:18:49:   Calculating solar irradiance...
    2025/09/10 17:18:49:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:49:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:49:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:50:   Reading metadata for VNIR detector...
    2025/09/10 17:18:50:   Calculating solar irradiance...
    2025/09/10 17:18:50:   Reading metadata for SWIR detector...
    2025/09/10 17:18:50:   Calculating solar irradiance...
    2025/09/10 17:18:50:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:50:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:50:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:50:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:18:50:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:18:50:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxcm799li/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:18:51:   L1B product successfully written!
    2025/09/10 17:18:51:   Reading Input Data
    2025/09/10 17:18:51:   Reading metadata for VNIR detector...
    2025/09/10 17:18:51:   Calculating solar irradiance...
    2025/09/10 17:18:51:   Reading metadata for SWIR detector...
    2025/09/10 17:18:51:   Calculating solar irradiance...
    2025/09/10 17:18:51:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:51:   Reading Input Data
    2025/09/10 17:18:51:   Reading metadata for VNIR detector...
    2025/09/10 17:18:51:   Calculating solar irradiance...
    2025/09/10 17:18:51:   Reading metadata for SWIR detector...
    2025/09/10 17:18:52:   Calculating solar irradiance...
    2025/09/10 17:18:52:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:52:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:52:   Reading metadata for VNIR detector...
    2025/09/10 17:18:52:   Calculating solar irradiance...
    2025/09/10 17:18:52:   Reading metadata for SWIR detector...
    2025/09/10 17:18:52:   Calculating solar irradiance...
    2025/09/10 17:18:52:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:52:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:53:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:53:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:18:53:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:18:53:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:18:53:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:18:53:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmprc0tu0ps/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:18:54:   L1B product successfully written!
    2025/09/10 17:18:54:   Reading Input Data
    2025/09/10 17:18:54:   Reading metadata for VNIR detector...
    2025/09/10 17:18:54:   Calculating solar irradiance...
    2025/09/10 17:18:54:   Reading metadata for SWIR detector...
    2025/09/10 17:18:54:   Calculating solar irradiance...
    2025/09/10 17:18:54:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:54:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:18:55:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:18:41:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:18:41:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:18:44:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:18:44:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:18:44:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:18:44:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:18:44:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:18:46:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:18:46:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:18:46:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:18:46:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:18:46:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:18:50:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:18:50:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:18:50:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:18:50:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:18:50:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:18:50:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:18:50:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:18:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:18:53:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:18:54:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:18:54:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:18:54:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:18:54:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:18:54:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_10_lines 0:00:15.255340

Started | 2025-09-10 17:18:55
Ended | 2025-09-10 17:19:11
Duration | 0:00:15.255340
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:18:56:   Reading Input Data
    2025/09/10 17:18:56:   Reading metadata for VNIR detector...
    2025/09/10 17:18:56:   Calculating solar irradiance...
    2025/09/10 17:18:56:   Reading metadata for SWIR detector...
    2025/09/10 17:18:56:   Calculating solar irradiance...
    2025/09/10 17:18:57:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:57:   Reading metadata for VNIR detector...
    2025/09/10 17:18:57:   Calculating solar irradiance...
    2025/09/10 17:18:57:   Reading metadata for SWIR detector...
    2025/09/10 17:18:57:   Calculating solar irradiance...
    2025/09/10 17:18:57:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:18:58:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:58:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:58:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:58:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:18:58:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpyaz4zk_n/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:18:58:   L1B product successfully written!
    2025/09/10 17:18:58:   Reading Input Data
    2025/09/10 17:18:58:   Reading metadata for VNIR detector...
    2025/09/10 17:18:58:   Calculating solar irradiance...
    2025/09/10 17:18:58:   Reading metadata for SWIR detector...
    2025/09/10 17:18:58:   Calculating solar irradiance...
    2025/09/10 17:18:59:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:59:   Reading Input Data
    2025/09/10 17:18:59:   Reading metadata for VNIR detector...
    2025/09/10 17:18:59:   Calculating solar irradiance...
    2025/09/10 17:18:59:   Reading metadata for SWIR detector...
    2025/09/10 17:18:59:   Calculating solar irradiance...
    2025/09/10 17:18:59:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:18:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:18:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:00:   Reading metadata for VNIR detector...
    2025/09/10 17:19:00:   Calculating solar irradiance...
    2025/09/10 17:19:00:   Reading metadata for SWIR detector...
    2025/09/10 17:19:00:   Calculating solar irradiance...
    2025/09/10 17:19:00:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:00:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:00:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:00:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:00:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:00:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:00:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:00:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:02:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:02:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpz_h9wpcw/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:02:   L1B product successfully written!
    2025/09/10 17:19:02:   Reading Input Data
    2025/09/10 17:19:02:   Reading metadata for VNIR detector...
    2025/09/10 17:19:02:   Calculating solar irradiance...
    2025/09/10 17:19:02:   Reading metadata for SWIR detector...
    2025/09/10 17:19:03:   Calculating solar irradiance...
    2025/09/10 17:19:03:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:03:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:04:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:04:   Reading Input Data
    2025/09/10 17:19:04:   Reading metadata for VNIR detector...
    2025/09/10 17:19:04:   Calculating solar irradiance...
    2025/09/10 17:19:04:   Reading metadata for SWIR detector...
    2025/09/10 17:19:04:   Calculating solar irradiance...
    2025/09/10 17:19:05:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:05:   Reading metadata for VNIR detector...
    2025/09/10 17:19:05:   Calculating solar irradiance...
    2025/09/10 17:19:05:   Reading metadata for SWIR detector...
    2025/09/10 17:19:05:   Calculating solar irradiance...
    2025/09/10 17:19:05:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:06:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:06:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:06:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpuh4yvk7_/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:06:   L1B product successfully written!
    2025/09/10 17:19:06:   Reading Input Data
    2025/09/10 17:19:06:   Reading metadata for VNIR detector...
    2025/09/10 17:19:06:   Calculating solar irradiance...
    2025/09/10 17:19:06:   Reading metadata for SWIR detector...
    2025/09/10 17:19:06:   Calculating solar irradiance...
    2025/09/10 17:19:06:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:06:   Reading Input Data
    2025/09/10 17:19:06:   Reading metadata for VNIR detector...
    2025/09/10 17:19:07:   Calculating solar irradiance...
    2025/09/10 17:19:07:   Reading metadata for SWIR detector...
    2025/09/10 17:19:07:   Calculating solar irradiance...
    2025/09/10 17:19:07:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:07:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:07:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:07:   Reading metadata for VNIR detector...
    2025/09/10 17:19:07:   Calculating solar irradiance...
    2025/09/10 17:19:07:   Reading metadata for SWIR detector...
    2025/09/10 17:19:08:   Calculating solar irradiance...
    2025/09/10 17:19:08:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:08:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:08:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:08:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:08:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:08:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:09:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:09:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpc11kqct2/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:09:   L1B product successfully written!
    2025/09/10 17:19:09:   Reading Input Data
    2025/09/10 17:19:09:   Reading metadata for VNIR detector...
    2025/09/10 17:19:09:   Calculating solar irradiance...
    2025/09/10 17:19:09:   Reading metadata for SWIR detector...
    2025/09/10 17:19:10:   Calculating solar irradiance...
    2025/09/10 17:19:10:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:10:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:10:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:18:58:   A minimum of 50 lines is required, only 10 were selected
    2025/09/10 17:18:58:   Set the number of line to 50
    2025/09/10 17:18:58:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:18:58:   A minimum of 50 lines is required, only 10 were selected
    2025/09/10 17:18:58:   Set the number of line to 50
    2025/09/10 17:18:58:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:18:58:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:00:   A minimum of 50 lines is required, only 10 were selected
    2025/09/10 17:19:00:   Set the number of line to 50
    2025/09/10 17:19:00:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:00:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:00:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:00:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:00:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:00:   A minimum of 50 lines is required, only 10 were selected
    2025/09/10 17:19:00:   Set the number of line to 50
    2025/09/10 17:19:02:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:02:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:02:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:02:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:02:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:06:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:06:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:06:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:06:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:06:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:06:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:08:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:08:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:09:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:09:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:09:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:09:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:09:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_150_lines 0:00:16.410263

Started | 2025-09-10 17:19:11
Ended | 2025-09-10 17:19:27
Duration | 0:00:16.410263
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:19:11:   Reading Input Data
    2025/09/10 17:19:11:   Reading metadata for VNIR detector...
    2025/09/10 17:19:11:   Calculating solar irradiance...
    2025/09/10 17:19:11:   Reading metadata for SWIR detector...
    2025/09/10 17:19:12:   Calculating solar irradiance...
    2025/09/10 17:19:12:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:12:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:12:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:12:   Reading metadata for VNIR detector...
    2025/09/10 17:19:12:   Calculating solar irradiance...
    2025/09/10 17:19:12:   Reading metadata for SWIR detector...
    2025/09/10 17:19:13:   Calculating solar irradiance...
    2025/09/10 17:19:13:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:13:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:13:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:13:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:13:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:13:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpfkp86jt6/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:13:   L1B product successfully written!
    2025/09/10 17:19:13:   Reading Input Data
    2025/09/10 17:19:13:   Reading metadata for VNIR detector...
    2025/09/10 17:19:14:   Calculating solar irradiance...
    2025/09/10 17:19:14:   Reading metadata for SWIR detector...
    2025/09/10 17:19:14:   Calculating solar irradiance...
    2025/09/10 17:19:14:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:14:   Reading Input Data
    2025/09/10 17:19:14:   Reading metadata for VNIR detector...
    2025/09/10 17:19:14:   Calculating solar irradiance...
    2025/09/10 17:19:14:   Reading metadata for SWIR detector...
    2025/09/10 17:19:15:   Calculating solar irradiance...
    2025/09/10 17:19:15:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:15:   Reading metadata for VNIR detector...
    2025/09/10 17:19:15:   Calculating solar irradiance...
    2025/09/10 17:19:15:   Reading metadata for SWIR detector...
    2025/09/10 17:19:15:   Calculating solar irradiance...
    2025/09/10 17:19:16:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:16:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:16:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:16:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:16:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:16:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:16:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:16:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:17:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:17:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpa6tb4tvl/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:18:   L1B product successfully written!
    2025/09/10 17:19:18:   Reading Input Data
    2025/09/10 17:19:18:   Reading metadata for VNIR detector...
    2025/09/10 17:19:18:   Calculating solar irradiance...
    2025/09/10 17:19:18:   Reading metadata for SWIR detector...
    2025/09/10 17:19:18:   Calculating solar irradiance...
    2025/09/10 17:19:18:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:19:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:20:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:20:   Reading Input Data
    2025/09/10 17:19:20:   Reading metadata for VNIR detector...
    2025/09/10 17:19:21:   Calculating solar irradiance...
    2025/09/10 17:19:21:   Reading metadata for SWIR detector...
    2025/09/10 17:19:21:   Calculating solar irradiance...
    2025/09/10 17:19:21:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:21:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:21:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:21:   Reading metadata for VNIR detector...
    2025/09/10 17:19:21:   Calculating solar irradiance...
    2025/09/10 17:19:21:   Reading metadata for SWIR detector...
    2025/09/10 17:19:22:   Calculating solar irradiance...
    2025/09/10 17:19:22:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:22:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:22:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:22:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:22:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:22:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_yr41oka/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:22:   L1B product successfully written!
    2025/09/10 17:19:22:   Reading Input Data
    2025/09/10 17:19:22:   Reading metadata for VNIR detector...
    2025/09/10 17:19:22:   Calculating solar irradiance...
    2025/09/10 17:19:22:   Reading metadata for SWIR detector...
    2025/09/10 17:19:23:   Calculating solar irradiance...
    2025/09/10 17:19:23:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:23:   Reading Input Data
    2025/09/10 17:19:23:   Reading metadata for VNIR detector...
    2025/09/10 17:19:23:   Calculating solar irradiance...
    2025/09/10 17:19:23:   Reading metadata for SWIR detector...
    2025/09/10 17:19:23:   Calculating solar irradiance...
    2025/09/10 17:19:23:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:23:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:23:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:24:   Reading metadata for VNIR detector...
    2025/09/10 17:19:24:   Calculating solar irradiance...
    2025/09/10 17:19:24:   Reading metadata for SWIR detector...
    2025/09/10 17:19:24:   Calculating solar irradiance...
    2025/09/10 17:19:24:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:24:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:24:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:24:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:25:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:25:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpolf64ywk/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:25:   L1B product successfully written!
    2025/09/10 17:19:25:   Reading Input Data
    2025/09/10 17:19:25:   Reading metadata for VNIR detector...
    2025/09/10 17:19:26:   Calculating solar irradiance...
    2025/09/10 17:19:26:   Reading metadata for SWIR detector...
    2025/09/10 17:19:26:   Calculating solar irradiance...
    2025/09/10 17:19:26:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:26:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:27:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:19:13:   n_lines (150) exceeds the total number of line of second image
    2025/09/10 17:19:13:   Set to the image number of line
    2025/09/10 17:19:13:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:13:   n_lines (150) exceeds the total number of line of second image
    2025/09/10 17:19:13:   Set to the image number of line
    2025/09/10 17:19:13:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:13:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:16:   n_lines (150) exceeds the total number of line of second image
    2025/09/10 17:19:16:   Set to the image number of line
    2025/09/10 17:19:16:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:16:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:16:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:16:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:16:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:16:   n_lines (150) exceeds the total number of line of second image
    2025/09/10 17:19:16:   Set to the image number of line
    2025/09/10 17:19:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:22:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:22:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:22:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:22:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:22:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:22:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:22:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:24:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:24:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:25:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:25:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:25:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:25:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:25:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_50_lines 0:00:17.472329

Started | 2025-09-10 17:19:27
Ended | 2025-09-10 17:19:44
Duration | 0:00:17.472329
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:19:28:   Reading Input Data
    2025/09/10 17:19:28:   Reading metadata for VNIR detector...
    2025/09/10 17:19:28:   Calculating solar irradiance...
    2025/09/10 17:19:28:   Reading metadata for SWIR detector...
    2025/09/10 17:19:28:   Calculating solar irradiance...
    2025/09/10 17:19:28:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:28:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:28:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:28:   Reading metadata for VNIR detector...
    2025/09/10 17:19:29:   Calculating solar irradiance...
    2025/09/10 17:19:29:   Reading metadata for SWIR detector...
    2025/09/10 17:19:29:   Calculating solar irradiance...
    2025/09/10 17:19:29:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:29:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:29:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:29:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:29:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:29:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:29:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:29:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpkcm62jje/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:30:   L1B product successfully written!
    2025/09/10 17:19:30:   Reading Input Data
    2025/09/10 17:19:30:   Reading metadata for VNIR detector...
    2025/09/10 17:19:30:   Calculating solar irradiance...
    2025/09/10 17:19:30:   Reading metadata for SWIR detector...
    2025/09/10 17:19:30:   Calculating solar irradiance...
    2025/09/10 17:19:30:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:30:   Reading Input Data
    2025/09/10 17:19:30:   Reading metadata for VNIR detector...
    2025/09/10 17:19:30:   Calculating solar irradiance...
    2025/09/10 17:19:30:   Reading metadata for SWIR detector...
    2025/09/10 17:19:31:   Calculating solar irradiance...
    2025/09/10 17:19:31:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:31:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:31:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:31:   Reading metadata for VNIR detector...
    2025/09/10 17:19:32:   Calculating solar irradiance...
    2025/09/10 17:19:32:   Reading metadata for SWIR detector...
    2025/09/10 17:19:32:   Calculating solar irradiance...
    2025/09/10 17:19:32:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:32:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:32:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:32:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:32:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:33:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:33:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:33:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:34:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:35:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (150, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (150, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (150, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (150, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp_5mhaslb/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:35:   L1B product successfully written!
    2025/09/10 17:19:35:   Reading Input Data
    2025/09/10 17:19:35:   Reading metadata for VNIR detector...
    2025/09/10 17:19:35:   Calculating solar irradiance...
    2025/09/10 17:19:36:   Reading metadata for SWIR detector...
    2025/09/10 17:19:36:   Calculating solar irradiance...
    2025/09/10 17:19:36:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:36:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:38:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:38:   Reading Input Data
    2025/09/10 17:19:38:   Reading metadata for VNIR detector...
    2025/09/10 17:19:38:   Calculating solar irradiance...
    2025/09/10 17:19:38:   Reading metadata for SWIR detector...
    2025/09/10 17:19:38:   Calculating solar irradiance...
    2025/09/10 17:19:38:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:38:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:38:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:39:   Reading metadata for VNIR detector...
    2025/09/10 17:19:39:   Calculating solar irradiance...
    2025/09/10 17:19:39:   Reading metadata for SWIR detector...
    2025/09/10 17:19:39:   Calculating solar irradiance...
    2025/09/10 17:19:39:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:39:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:39:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:39:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:39:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:39:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpxut2owu0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:40:   L1B product successfully written!
    2025/09/10 17:19:40:   Reading Input Data
    2025/09/10 17:19:40:   Reading metadata for VNIR detector...
    2025/09/10 17:19:40:   Calculating solar irradiance...
    2025/09/10 17:19:40:   Reading metadata for SWIR detector...
    2025/09/10 17:19:40:   Calculating solar irradiance...
    2025/09/10 17:19:40:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:40:   Reading Input Data
    2025/09/10 17:19:40:   Reading metadata for VNIR detector...
    2025/09/10 17:19:40:   Calculating solar irradiance...
    2025/09/10 17:19:40:   Reading metadata for SWIR detector...
    2025/09/10 17:19:41:   Calculating solar irradiance...
    2025/09/10 17:19:41:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:41:   Reading metadata for VNIR detector...
    2025/09/10 17:19:41:   Calculating solar irradiance...
    2025/09/10 17:19:41:   Reading metadata for SWIR detector...
    2025/09/10 17:19:41:   Calculating solar irradiance...
    2025/09/10 17:19:42:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:42:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:42:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:42:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:42:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:42:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:43:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:43:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzs1yk06d/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:43:   L1B product successfully written!
    2025/09/10 17:19:43:   Reading Input Data
    2025/09/10 17:19:43:   Reading metadata for VNIR detector...
    2025/09/10 17:19:43:   Calculating solar irradiance...
    2025/09/10 17:19:43:   Reading metadata for SWIR detector...
    2025/09/10 17:19:43:   Calculating solar irradiance...
    2025/09/10 17:19:43:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:44:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:44:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:19:29:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:29:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:33:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:33:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:33:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:33:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:33:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:35:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:35:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:35:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:35:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:35:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:39:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:39:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:39:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:39:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:39:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:39:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:39:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:42:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:42:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:43:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:43:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:43:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:43:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:43:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_80_lines 0:00:15.773526

Started | 2025-09-10 17:19:44
Ended | 2025-09-10 17:20:00
Duration | 0:00:15.773526
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:19:45:   Reading Input Data
    2025/09/10 17:19:45:   Reading metadata for VNIR detector...
    2025/09/10 17:19:45:   Calculating solar irradiance...
    2025/09/10 17:19:45:   Reading metadata for SWIR detector...
    2025/09/10 17:19:46:   Calculating solar irradiance...
    2025/09/10 17:19:46:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:46:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:46:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:46:   Reading metadata for VNIR detector...
    2025/09/10 17:19:46:   Calculating solar irradiance...
    2025/09/10 17:19:46:   Reading metadata for SWIR detector...
    2025/09/10 17:19:46:   Calculating solar irradiance...
    2025/09/10 17:19:46:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:47:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:47:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:47:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:47:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:47:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5u1k4ki1/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:47:   L1B product successfully written!
    2025/09/10 17:19:47:   Reading Input Data
    2025/09/10 17:19:47:   Reading metadata for VNIR detector...
    2025/09/10 17:19:47:   Calculating solar irradiance...
    2025/09/10 17:19:47:   Reading metadata for SWIR detector...
    2025/09/10 17:19:48:   Calculating solar irradiance...
    2025/09/10 17:19:48:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:48:   Reading Input Data
    2025/09/10 17:19:48:   Reading metadata for VNIR detector...
    2025/09/10 17:19:48:   Calculating solar irradiance...
    2025/09/10 17:19:48:   Reading metadata for SWIR detector...
    2025/09/10 17:19:48:   Calculating solar irradiance...
    2025/09/10 17:19:49:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:49:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:49:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:49:   Reading metadata for VNIR detector...
    2025/09/10 17:19:49:   Calculating solar irradiance...
    2025/09/10 17:19:49:   Reading metadata for SWIR detector...
    2025/09/10 17:19:49:   Calculating solar irradiance...
    2025/09/10 17:19:49:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:49:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:49:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:50:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:50:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:50:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:50:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:19:50:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:51:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:51:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (180, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (180, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (180, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (180, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpg0qrje3y/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:19:52:   L1B product successfully written!
    2025/09/10 17:19:52:   Reading Input Data
    2025/09/10 17:19:52:   Reading metadata for VNIR detector...
    2025/09/10 17:19:52:   Calculating solar irradiance...
    2025/09/10 17:19:52:   Reading metadata for SWIR detector...
    2025/09/10 17:19:52:   Calculating solar irradiance...
    2025/09/10 17:19:52:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:52:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:54:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:54:   Reading Input Data
    2025/09/10 17:19:54:   Reading metadata for VNIR detector...
    2025/09/10 17:19:54:   Calculating solar irradiance...
    2025/09/10 17:19:54:   Reading metadata for SWIR detector...
    2025/09/10 17:19:54:   Calculating solar irradiance...
    2025/09/10 17:19:54:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:55:   Reading metadata for VNIR detector...
    2025/09/10 17:19:55:   Calculating solar irradiance...
    2025/09/10 17:19:55:   Reading metadata for SWIR detector...
    2025/09/10 17:19:55:   Calculating solar irradiance...
    2025/09/10 17:19:55:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:55:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:55:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:55:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:55:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:55:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpzdo7sq0q/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:56:   L1B product successfully written!
    2025/09/10 17:19:56:   Reading Input Data
    2025/09/10 17:19:56:   Reading metadata for VNIR detector...
    2025/09/10 17:19:56:   Calculating solar irradiance...
    2025/09/10 17:19:56:   Reading metadata for SWIR detector...
    2025/09/10 17:19:56:   Calculating solar irradiance...
    2025/09/10 17:19:56:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:56:   Reading Input Data
    2025/09/10 17:19:56:   Reading metadata for VNIR detector...
    2025/09/10 17:19:56:   Calculating solar irradiance...
    2025/09/10 17:19:56:   Reading metadata for SWIR detector...
    2025/09/10 17:19:57:   Calculating solar irradiance...
    2025/09/10 17:19:57:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:57:   Reading metadata for VNIR detector...
    2025/09/10 17:19:57:   Calculating solar irradiance...
    2025/09/10 17:19:57:   Reading metadata for SWIR detector...
    2025/09/10 17:19:57:   Calculating solar irradiance...
    2025/09/10 17:19:57:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:57:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:19:57:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:19:58:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:58:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:19:58:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:19:58:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:19:59:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp5q619en0/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:19:59:   L1B product successfully written!
    2025/09/10 17:19:59:   Reading Input Data
    2025/09/10 17:19:59:   Reading metadata for VNIR detector...
    2025/09/10 17:19:59:   Calculating solar irradiance...
    2025/09/10 17:19:59:   Reading metadata for SWIR detector...
    2025/09/10 17:19:59:   Calculating solar irradiance...
    2025/09/10 17:19:59:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:19:59:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:00:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:19:47:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:47:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:50:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:19:50:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:19:50:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:19:50:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:19:50:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:19:51:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:51:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:51:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:51:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:51:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:55:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:55:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:55:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:55:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:55:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:55:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:55:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:19:58:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:58:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:19:59:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:19:59:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:19:59:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:19:59:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:19:59:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_append_all_lines 0:00:16.421301

Started | 2025-09-10 17:20:00
Ended | 2025-09-10 17:20:17
Duration | 0:00:16.421301
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:01:   Reading Input Data
    2025/09/10 17:20:01:   Reading metadata for VNIR detector...
    2025/09/10 17:20:01:   Calculating solar irradiance...
    2025/09/10 17:20:01:   Reading metadata for SWIR detector...
    2025/09/10 17:20:01:   Calculating solar irradiance...
    2025/09/10 17:20:01:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:01:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:01:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:02:   Reading metadata for VNIR detector...
    2025/09/10 17:20:02:   Calculating solar irradiance...
    2025/09/10 17:20:02:   Reading metadata for SWIR detector...
    2025/09/10 17:20:02:   Calculating solar irradiance...
    2025/09/10 17:20:02:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:02:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:02:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:02:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:02:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:03:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:03:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:03:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpmnb73yyi/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:20:03:   L1B product successfully written!
    2025/09/10 17:20:03:   Reading Input Data
    2025/09/10 17:20:03:   Reading metadata for VNIR detector...
    2025/09/10 17:20:03:   Calculating solar irradiance...
    2025/09/10 17:20:03:   Reading metadata for SWIR detector...
    2025/09/10 17:20:04:   Calculating solar irradiance...
    2025/09/10 17:20:04:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:04:   Reading Input Data
    2025/09/10 17:20:04:   Reading metadata for VNIR detector...
    2025/09/10 17:20:04:   Calculating solar irradiance...
    2025/09/10 17:20:04:   Reading metadata for SWIR detector...
    2025/09/10 17:20:04:   Calculating solar irradiance...
    2025/09/10 17:20:04:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:04:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:04:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:05:   Reading metadata for VNIR detector...
    2025/09/10 17:20:05:   Calculating solar irradiance...
    2025/09/10 17:20:05:   Reading metadata for SWIR detector...
    2025/09/10 17:20:05:   Calculating solar irradiance...
    2025/09/10 17:20:05:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:05:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:05:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:05:   Check new image for VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:05:   Append new image to VNIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:05:   Check new image for SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:05:   Append new image to SWIR: AlpineTest2_CWV2_SM0
    2025/09/10 17:20:05:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:07:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:07:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (200, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (200, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (200, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (200, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp4mb1cmwg/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:20:08:   L1B product successfully written!
    2025/09/10 17:20:08:   Reading Input Data
    2025/09/10 17:20:08:   Reading metadata for VNIR detector...
    2025/09/10 17:20:08:   Calculating solar irradiance...
    2025/09/10 17:20:08:   Reading metadata for SWIR detector...
    2025/09/10 17:20:08:   Calculating solar irradiance...
    2025/09/10 17:20:08:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:08:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:10:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:10:   Reading Input Data
    2025/09/10 17:20:10:   Reading metadata for VNIR detector...
    2025/09/10 17:20:10:   Calculating solar irradiance...
    2025/09/10 17:20:10:   Reading metadata for SWIR detector...
    2025/09/10 17:20:11:   Calculating solar irradiance...
    2025/09/10 17:20:11:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:11:   Reading metadata for VNIR detector...
    2025/09/10 17:20:11:   Calculating solar irradiance...
    2025/09/10 17:20:11:   Reading metadata for SWIR detector...
    2025/09/10 17:20:11:   Calculating solar irradiance...
    2025/09/10 17:20:11:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:11:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:11:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:12:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:20:12:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:20:12:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmpj46wzpjh/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:20:12:   L1B product successfully written!
    2025/09/10 17:20:12:   Reading Input Data
    2025/09/10 17:20:12:   Reading metadata for VNIR detector...
    2025/09/10 17:20:12:   Calculating solar irradiance...
    2025/09/10 17:20:12:   Reading metadata for SWIR detector...
    2025/09/10 17:20:12:   Calculating solar irradiance...
    2025/09/10 17:20:12:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:12:   Reading Input Data
    2025/09/10 17:20:12:   Reading metadata for VNIR detector...
    2025/09/10 17:20:13:   Calculating solar irradiance...
    2025/09/10 17:20:13:   Reading metadata for SWIR detector...
    2025/09/10 17:20:13:   Calculating solar irradiance...
    2025/09/10 17:20:13:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:13:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:13:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:13:   Reading metadata for VNIR detector...
    2025/09/10 17:20:13:   Calculating solar irradiance...
    2025/09/10 17:20:13:   Reading metadata for SWIR detector...
    2025/09/10 17:20:14:   Calculating solar irradiance...
    2025/09/10 17:20:14:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:14:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:14:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:14:   Check new image for VNIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:20:14:   Check new image for SWIR: AlpineTest1_CWV2_SM0
    2025/09/10 17:20:14:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:15:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:15:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp61uho98r/EnMAP_AlpineTest2_D1/EnMAP_AlpineTest2_D2_quicklook.png.
    2025/09/10 17:20:15:   L1B product successfully written!
    2025/09/10 17:20:15:   Reading Input Data
    2025/09/10 17:20:15:   Reading metadata for VNIR detector...
    2025/09/10 17:20:15:   Calculating solar irradiance...
    2025/09/10 17:20:15:   Reading metadata for SWIR detector...
    2025/09/10 17:20:16:   Calculating solar irradiance...
    2025/09/10 17:20:16:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:16:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:17:   Computing SNR from SWIR TOA radiance.

##### Captured stderr call

    2025/09/10 17:20:03:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:03:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:20:05:   Could not append the 'mask_landwater' attribute as it does not exist in the current image.
    2025/09/10 17:20:05:   Could not append the 'mask_cloudshadow' attribute as it does not exist in the current image.
    2025/09/10 17:20:05:   Could not append the 'mask_haze' attribute as it does not exist in the current image.
    2025/09/10 17:20:05:   Could not append the 'mask_snow' attribute as it does not exist in the current image.
    2025/09/10 17:20:05:   Could not append the 'mask_cirrus' attribute as it does not exist in the current image.
    2025/09/10 17:20:07:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:07:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:07:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:07:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:07:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:20:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:20:12:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:20:12:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:12:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:12:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:12:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:12:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.
    2025/09/10 17:20:14:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:20:14:   AlpineTest2_CWV2_SM0 and AlpineTest1_CWV2_SM0 don't fit to be appended.
    2025/09/10 17:20:15:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:15:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:15:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:15:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:15:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_no_snr 0:00:02.303205

Test to read test image 1, save it and read the saved result again - without SNR.

Started | 2025-09-10 17:20:17
Ended | 2025-09-10 17:20:19
Duration | 0:00:02.303205
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:17:   Reading Input Data
    2025/09/10 17:20:17:   Reading metadata for VNIR detector...
    2025/09/10 17:20:18:   Calculating solar irradiance...
    2025/09/10 17:20:18:   Reading metadata for SWIR detector...
    2025/09/10 17:20:18:   Calculating solar irradiance...
    2025/09/10 17:20:18:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:18:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:18:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmp7_tvwnha/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:20:18:   L1B product successfully written!
    2025/09/10 17:20:18:   Reading Input Data
    2025/09/10 17:20:18:   Reading metadata for VNIR detector...
    2025/09/10 17:20:19:   Calculating solar irradiance...
    2025/09/10 17:20:19:   Reading metadata for SWIR detector...
    2025/09/10 17:20:19:   Calculating solar irradiance...
    2025/09/10 17:20:19:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/10 17:20:18:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:18:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:18:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:18:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:18:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader::test_read_and_save_single_image_with_snr 0:00:03.316714

Test to read test image 1, save it and read the saved result again - with SNR.

Started | 2025-09-10 17:20:19
Ended | 2025-09-10 17:20:22
Duration | 0:00:03.316714
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:20:   Reading Input Data
    2025/09/10 17:20:20:   Reading metadata for VNIR detector...
    2025/09/10 17:20:20:   Calculating solar irradiance...
    2025/09/10 17:20:20:   Reading metadata for SWIR detector...
    2025/09/10 17:20:20:   Calculating solar irradiance...
    2025/09/10 17:20:20:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:20:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:20:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:20:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:21:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:21:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1.bsq.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_cloudmask.tif.
    Writing GeoArray of size (88, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D1_quicklook.png.
    Writing GeoArray of size (100, 1000, 154) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2.bsq.
    Writing GeoArray of size (154, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_deadpixelmap.tif.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/tmptw_z17rj/EnMAP_AlpineTest1_D1/EnMAP_AlpineTest1_D2_quicklook.png.
    2025/09/10 17:20:22:   L1B product successfully written!
    2025/09/10 17:20:22:   Reading Input Data
    2025/09/10 17:20:22:   Reading metadata for VNIR detector...
    2025/09/10 17:20:22:   Calculating solar irradiance...
    2025/09/10 17:20:22:   Reading metadata for SWIR detector...
    2025/09/10 17:20:22:   Calculating solar irradiance...
    2025/09/10 17:20:22:   Reading image masks in VNIR sensor geometry.

##### Captured stderr call

    2025/09/10 17:20:21:   Could not save the VNIR attribute 'mask_landwater' as it does not exist in the current image.
    2025/09/10 17:20:21:   Could not save the VNIR attribute 'mask_cloudshadow' as it does not exist in the current image.
    2025/09/10 17:20:21:   Could not save the VNIR attribute 'mask_haze' as it does not exist in the current image.
    2025/09/10 17:20:21:   Could not save the VNIR attribute 'mask_snow' as it does not exist in the current image.
    2025/09/10 17:20:21:   Could not save the VNIR attribute 'mask_cirrus' as it does not exist in the current image.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata 0:00:02.375728

Started | 2025-09-10 17:20:22
Ended | 2025-09-10 17:20:25
Duration | 0:00:02.375728
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:22:   Reading Input Data
    2025/09/10 17:20:23:   Reading metadata for VNIR detector...
    2025/09/10 17:20:23:   Calculating solar irradiance...
    2025/09/10 17:20:23:   Reading metadata for SWIR detector...
    2025/09/10 17:20:23:   Calculating solar irradiance...
    2025/09/10 17:20:23:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:24:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:24:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:24:   Computing VNIR geolayer...
    2025/09/10 17:20:24:   Computing SWIR geolayer...
    2025/09/10 17:20:24:   Write product to: /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_VNIR.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLASSES.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUD.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CLOUDSHADOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_HAZE.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_SNOW.TIF.
    Writing GeoArray of size (100, 1000) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_QUALITY_CIRRUS.TIF.
    Writing GeoArray of size (100, 1000, 88) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_VNIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_VNIR.png.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-SPECTRAL_IMAGE_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 124) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_PIXELMASK_SWIR.TIF.
    Writing GeoArray of size (100, 1000, 3) to /builds/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT/tests/data/test_outputs/no_snr/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z/ENMAP01-____L1B-DT000400126_20170218T110115Z_002_V000204_20200206T182719Z-QL_SWIR.png.
    2025/09/10 17:20:25:   L1B product successfully written!

##### Captured stderr call

    2025/09/10 17:20:23:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_L1B_Reader_DLR::test_read_inputdata_dont_drop_bad_bands 0:00:01.790154

Started | 2025-09-10 17:20:25
Ended | 2025-09-10 17:20:26
Duration | 0:00:01.790154
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:25:   Reading Input Data
    2025/09/10 17:20:25:   Reading metadata for VNIR detector...
    2025/09/10 17:20:25:   Calculating solar irradiance...
    2025/09/10 17:20:25:   Reading metadata for SWIR detector...
    2025/09/10 17:20:25:   Calculating solar irradiance...
    2025/09/10 17:20:26:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:26:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:26:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:26:   Computing VNIR geolayer...
    2025/09/10 17:20:26:   Computing SWIR geolayer...

##### Captured stderr call

    2025/09/10 17:20:25:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_orthorectification.py 10 0:00:26.485990

### PASSED Test_Orthorectifier::test_run_transformation_ll 0:00:05.793365

Started | 2025-09-10 17:20:26
Ended | 2025-09-10 17:20:32
Duration | 0:00:05.793365
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:27:   Reading Input Data
    2025/09/10 17:20:27:   Reading metadata for VNIR detector...
    2025/09/10 17:20:27:   Calculating solar irradiance...
    2025/09/10 17:20:27:   Reading metadata for SWIR detector...
    2025/09/10 17:20:27:   Calculating solar irradiance...
    2025/09/10 17:20:27:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:27:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:27:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:28:   Starting orthorectification...
    2025/09/10 17:20:28:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (10.691214991975885, 47.455058810417405, 11.070768, 47.540321)
    2025/09/10 17:20:28:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:29:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:30:   Merging VNIR and SWIR data...
    2025/09/10 17:20:30:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:20:30:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:20:31:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier::test_run_transformation_utm 0:00:06.904036

Started | 2025-09-10 17:20:32
Ended | 2025-09-10 17:20:39
Duration | 0:00:06.904036
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:33:   Reading Input Data
    2025/09/10 17:20:33:   Reading metadata for VNIR detector...
    2025/09/10 17:20:33:   Calculating solar irradiance...
    2025/09/10 17:20:33:   Reading metadata for SWIR detector...
    2025/09/10 17:20:34:   Calculating solar irradiance...
    2025/09/10 17:20:34:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:34:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:34:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:34:   Starting orthorectification...
    2025/09/10 17:20:34:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32632): (627300.0, 5257770.0, 656040.0, 5266620.0)
    2025/09/10 17:20:34:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:35:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:37:   Merging VNIR and SWIR data...
    2025/09/10 17:20:37:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:20:38:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:20:38:   Generating L2A metadata...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_ll 0:00:06.894834

Started | 2025-09-10 17:20:39
Ended | 2025-09-10 17:20:46
Duration | 0:00:06.894834
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:39:   Reading Input Data
    2025/09/10 17:20:39:   Reading metadata for VNIR detector...
    2025/09/10 17:20:40:   Calculating solar irradiance...
    2025/09/10 17:20:40:   Reading metadata for SWIR detector...
    2025/09/10 17:20:40:   Calculating solar irradiance...
    2025/09/10 17:20:40:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:41:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:41:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:41:   Computing VNIR geolayer...
    2025/09/10 17:20:41:   Computing SWIR geolayer...
    2025/09/10 17:20:41:   Starting orthorectification...
    2025/09/10 17:20:41:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 4326): (-1.2717290915354968, 44.60009471477741, -0.9054060033197534, 44.68406888113938)
    2025/09/10 17:20:41:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:42:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:43:   Merging VNIR and SWIR data...
    2025/09/10 17:20:43:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:20:44:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:20:44:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:20:44:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:20:44:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:20:44:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:20:45:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:20:45:   Generating L2A metadata...

##### Captured stderr call

    2025/09/10 17:20:39:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Orthorectifier_DLR::test_run_transformation_utm 0:00:06.877949

Started | 2025-09-10 17:20:46
Ended | 2025-09-10 17:20:53
Duration | 0:00:06.877949
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:46:   Reading Input Data
    2025/09/10 17:20:46:   Reading metadata for VNIR detector...
    2025/09/10 17:20:47:   Calculating solar irradiance...
    2025/09/10 17:20:47:   Reading metadata for SWIR detector...
    2025/09/10 17:20:47:   Calculating solar irradiance...
    2025/09/10 17:20:47:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:47:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:47:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:48:   Computing VNIR geolayer...
    2025/09/10 17:20:48:   Computing SWIR geolayer...
    2025/09/10 17:20:48:   Starting orthorectification...
    2025/09/10 17:20:48:   Computed common target extent of orthorectified image (xmin, ymin, xmax, ymax in EPSG 32630): (636990.0, 4940640.0, 666180.0, 4949340.0)
    2025/09/10 17:20:48:   Orthorectifying VNIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:49:   Orthorectifying SWIR data using 'bilinear' resampling algorithm...
    2025/09/10 17:20:50:   Merging VNIR and SWIR data...
    2025/09/10 17:20:50:   Orthorectifying 'mask_landwater' attribute...
    2025/09/10 17:20:50:   Orthorectifying 'mask_clouds' attribute...
    2025/09/10 17:20:51:   Orthorectifying 'mask_cloudshadow' attribute...
    2025/09/10 17:20:51:   Orthorectifying 'mask_haze' attribute...
    2025/09/10 17:20:51:   Orthorectifying 'mask_snow' attribute...
    2025/09/10 17:20:51:   Orthorectifying 'mask_cirrus' attribute...
    2025/09/10 17:20:51:   Setting all pixels to nodata that have values in the VNIR or the SWIR only...
    2025/09/10 17:20:52:   Generating L2A metadata...

##### Captured stderr call

    2025/09/10 17:20:46:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_compute_stack 0:00:00.003236

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.003236
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_average 0:00:00.002866

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.002866
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_order_by_wvl 0:00:00.002284

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.002284
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_swir_only 0:00:00.001941

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.001941
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_get_stack_vnir_only 0:00:00.001940

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.001940
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_Stacker::test_validate_input 0:00:00.003539

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:53
Duration | 0:00:00.003539
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_radiometric_transform.py 1 0:00:04.323297

### PASSED Test_Radiometric_Transformer::test_transform_TOARad2TOARef 0:00:04.323297

Started | 2025-09-10 17:20:53
Ended | 2025-09-10 17:20:57
Duration | 0:00:04.323297
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    Tmp dir: /tmp/tmp1twyf35b
    2025/09/10 17:20:53:   Reading Input Data
    2025/09/10 17:20:53:   Reading metadata for VNIR detector...
    2025/09/10 17:20:54:   Calculating solar irradiance...
    2025/09/10 17:20:54:   Reading metadata for SWIR detector...
    2025/09/10 17:20:54:   Calculating solar irradiance...
    2025/09/10 17:20:54:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:54:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:54:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:54:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:55:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:55:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/10 17:20:55:   Converting TOA radiance to TOA reflectance for SWIR detector...
    Tmp dir: /tmp/tmpmg89_e91
    2025/09/10 17:20:55:   Reading Input Data
    2025/09/10 17:20:56:   Reading metadata for VNIR detector...
    2025/09/10 17:20:56:   Calculating solar irradiance...
    2025/09/10 17:20:56:   Reading metadata for SWIR detector...
    2025/09/10 17:20:56:   Calculating solar irradiance...
    2025/09/10 17:20:56:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:56:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:56:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:56:   Computing SNR from VNIR TOA radiance.
    2025/09/10 17:20:57:   Computing SNR from SWIR TOA radiance.
    2025/09/10 17:20:57:   Converting TOA radiance to TOA reflectance for VNIR detector...
    2025/09/10 17:20:57:   Converting TOA radiance to TOA reflectance for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data
    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_optimization.py 1 0:00:16.516284

### PASSED Test_Spatial_Optimizer::test_optimize_geolayer 0:00:16.516284

Started | 2025-09-10 17:20:57
Ended | 2025-09-10 17:21:14
Duration | 0:00:16.516284
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:20:57:   Reading Input Data
    2025/09/10 17:20:58:   Reading metadata for VNIR detector...
    2025/09/10 17:20:58:   Calculating solar irradiance...
    2025/09/10 17:20:58:   Reading metadata for SWIR detector...
    2025/09/10 17:20:58:   Calculating solar irradiance...
    2025/09/10 17:20:58:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:20:59:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:20:59:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:20:59:   Computing VNIR geolayer...
    2025/09/10 17:20:59:   Computing SWIR geolayer...
    2025/09/10 17:20:59:   Temporarily transforming EnMAP band 40 to map geometry for co-registration.
    2025/09/10 17:20:59:   Temporarily transforming EnMAP water mask to map geometry for co-registration.
    2025/09/10 17:21:00:   Preparing reference image for co-registration.
    2025/09/10 17:21:00:   Computing tie points between the EnMAP image and the given spatial reference image.
    Calculating footprint polygon and actual data corner coordinates for reference image...
    Bounding box of calculated footprint for reference image:
    	(637005.0, 4940640.0, 666300.0, 4949895.0)
    Bounding box of calculated footprint for image to be shifted:
    	(637009.9236523756, 4940648.633479693, 666298.6703669054, 4949893.375184522)
    Matching window position (X,Y): 651655.4222751356/4945271.096554121
    Target window size (256, 256) not possible due to too small overlap area or window position too close to an image edge. New matching window size: (164, 164).
    Initializing tie points grid...
    With respect to the provided bad data mask(s) 81 points of initially 242 have been excluded.
    Calculating tie point grid (161 points) using 24 CPU cores...
    Found 131 matches.
    Performing validity checks...
    41 tie points flagged by level 1 filtering (reliability).
    63 tie points flagged by level 2 filtering (SSIM).
    4 tie points flagged by level 3 filtering (RANSAC)
    47 valid tie points remain after filtering.
    2025/09/10 17:21:13:   Generating misregistration array.
    interpolation runtime: 0.19s
    interpolation runtime: 0.17s
    2025/09/10 17:21:13:   Transforming spatial optimization results back to sensor geometry.
    2025/09/10 17:21:14:   Applying results of spatial optimization to geolayer.

##### Captured stderr call

    2025/09/10 17:20:58:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.
    2025/09/10 17:20:59:   Statically using band 40 for co-registration.

    Warping progress     |--------------------------------------------------| 0.0% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 1.5% Complete  => 0:00:00
    Warping progress     |=-------------------------------------------------| 2.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 3.1% Complete  => 0:00:00
    Warping progress     |==------------------------------------------------| 4.1% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 5.2% Complete  => 0:00:00
    Warping progress     |===-----------------------------------------------| 6.2% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 7.3% Complete  => 0:00:00
    Warping progress     |====----------------------------------------------| 8.3% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 9.1% Complete  => 0:00:00
    Warping progress     |=====---------------------------------------------| 10.2% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 11.0% Complete  => 0:00:00
    Warping progress     |======--------------------------------------------| 12.2% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 13.5% Complete  => 0:00:00
    Warping progress     |=======-------------------------------------------| 14.4% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 15.1% Complete  => 0:00:00
    Warping progress     |========------------------------------------------| 16.2% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 17.0% Complete  => 0:00:00
    Warping progress     |=========-----------------------------------------| 18.3% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 19.1% Complete  => 0:00:00
    Warping progress     |==========----------------------------------------| 20.3% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 21.1% Complete  => 0:00:00
    Warping progress     |===========---------------------------------------| 22.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 23.0% Complete  => 0:00:00
    Warping progress     |============--------------------------------------| 24.6% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 25.4% Complete  => 0:00:00
    Warping progress     |=============-------------------------------------| 26.3% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 27.1% Complete  => 0:00:00
    Warping progress     |==============------------------------------------| 28.0% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 29.7% Complete  => 0:00:00
    Warping progress     |===============-----------------------------------| 30.1% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 31.3% Complete  => 0:00:00
    Warping progress     |================----------------------------------| 32.3% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 33.2% Complete  => 0:00:00
    Warping progress     |=================---------------------------------| 34.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 35.2% Complete  => 0:00:00
    Warping progress     |==================--------------------------------| 36.1% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 37.4% Complete  => 0:00:00
    Warping progress     |===================-------------------------------| 38.7% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 39.1% Complete  => 0:00:00
    Warping progress     |====================------------------------------| 40.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 41.2% Complete  => 0:00:00
    Warping progress     |=====================-----------------------------| 42.1% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 43.3% Complete  => 0:00:00
    Warping progress     |======================----------------------------| 44.4% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 45.4% Complete  => 0:00:00
    Warping progress     |=======================---------------------------| 46.4% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 47.0% Complete  => 0:00:00
    Warping progress     |========================--------------------------| 48.6% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 49.1% Complete  => 0:00:00
    Warping progress     |=========================-------------------------| 50.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 51.2% Complete  => 0:00:00
    Warping progress     |==========================------------------------| 52.0% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 53.2% Complete  => 0:00:00
    Warping progress     |===========================-----------------------| 54.1% Complete  => 0:00:00
    Warping progress     |============================----------------------| 55.4% Complete  => 0:00:00
    Warping progress     |============================----------------------| 56.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 57.1% Complete  => 0:00:00
    Warping progress     |=============================---------------------| 58.0% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 59.2% Complete  => 0:00:00
    Warping progress     |==============================--------------------| 60.1% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 61.3% Complete  => 0:00:00
    Warping progress     |===============================-------------------| 62.4% Complete  => 0:00:00
    Warping progress     |================================------------------| 63.0% Complete  => 0:00:00
    Warping progress     |================================------------------| 64.3% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 65.5% Complete  => 0:00:00
    Warping progress     |=================================-----------------| 66.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 67.1% Complete  => 0:00:00
    Warping progress     |==================================----------------| 68.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 69.2% Complete  => 0:00:00
    Warping progress     |===================================---------------| 70.5% Complete  => 0:00:00
    Warping progress     |====================================--------------| 71.2% Complete  => 0:00:00
    Warping progress     |====================================--------------| 72.3% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 73.4% Complete  => 0:00:00
    Warping progress     |=====================================-------------| 74.6% Complete  => 0:00:00
    Warping progress     |======================================------------| 75.0% Complete  => 0:00:00
    Warping progress     |======================================------------| 76.0% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 77.1% Complete  => 0:00:00
    Warping progress     |=======================================-----------| 78.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 79.1% Complete  => 0:00:00
    Warping progress     |========================================----------| 80.2% Complete  => 0:00:00
    Warping progress     |=========================================---------| 81.0% Complete  => 0:00:00
    Warping progress     |=========================================---------| 82.0% Complete  => 0:00:00
    Warping progress     |==========================================--------| 83.1% Complete  => 0:00:00
    Warping progress     |==========================================--------| 84.1% Complete  => 0:00:00
    Warping progress     |===========================================-------| 85.3% Complete  => 0:00:00
    Warping progress     |===========================================-------| 86.1% Complete  => 0:00:00
    Warping progress     |============================================------| 87.0% Complete  => 0:00:00
    Warping progress     |============================================------| 88.0% Complete  => 0:00:00
    Warping progress     |=============================================-----| 89.1% Complete  => 0:00:00
    Warping progress     |=============================================-----| 90.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 91.1% Complete  => 0:00:00
    Warping progress     |==============================================----| 92.1% Complete  => 0:00:00
    Warping progress     |===============================================---| 93.0% Complete  => 0:00:00
    Warping progress     |===============================================---| 94.0% Complete  => 0:00:00
    Warping progress     |================================================--| 95.1% Complete  => 0:00:00
    Warping progress     |================================================--| 96.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 97.1% Complete  => 0:00:00
    Warping progress     |=================================================-| 98.1% Complete  => 0:00:00
    Warping progress     |==================================================| 99.0% Complete  => 0:00:00
    Warping progress     |==================================================| 100.0% Complete  => 0:00:00

    	progress: |--------------------------------------------------| 0.6% Complete  => 0:00:09
    	progress: |=-------------------------------------------------| 1.2% Complete  => 0:00:11
    	progress: |=-------------------------------------------------| 1.9% Complete  => 0:00:11
    	progress: |=-------------------------------------------------| 2.5% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.1% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 3.7% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 4.3% Complete  => 0:00:11
    	progress: |==------------------------------------------------| 5.0% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 5.6% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.2% Complete  => 0:00:11
    	progress: |===-----------------------------------------------| 6.8% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 7.5% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.1% Complete  => 0:00:11
    	progress: |====----------------------------------------------| 8.7% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.3% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 9.9% Complete  => 0:00:11
    	progress: |=====---------------------------------------------| 10.6% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.2% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 11.8% Complete  => 0:00:11
    	progress: |======--------------------------------------------| 12.4% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.0% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 13.7% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.3% Complete  => 0:00:11
    	progress: |=======-------------------------------------------| 14.9% Complete  => 0:00:12
    	progress: |========------------------------------------------| 15.5% Complete  => 0:00:12
    	progress: |========------------------------------------------| 16.1% Complete  => 0:00:12
    	progress: |========------------------------------------------| 16.8% Complete  => 0:00:12
    	progress: |=========-----------------------------------------| 17.4% Complete  => 0:00:12
    	progress: |=========-----------------------------------------| 18.0% Complete  => 0:00:12
    	progress: |=========-----------------------------------------| 18.6% Complete  => 0:00:12
    	progress: |==========----------------------------------------| 19.3% Complete  => 0:00:12
    	progress: |==========----------------------------------------| 19.9% Complete  => 0:00:12
    	progress: |==========----------------------------------------| 20.5% Complete  => 0:00:12
    	progress: |===========---------------------------------------| 21.1% Complete  => 0:00:12
    	progress: |===========---------------------------------------| 21.7% Complete  => 0:00:12
    	progress: |===========---------------------------------------| 22.4% Complete  => 0:00:12
    	progress: |===========---------------------------------------| 23.0% Complete  => 0:00:12
    	progress: |============--------------------------------------| 23.6% Complete  => 0:00:12
    	progress: |============--------------------------------------| 24.2% Complete  => 0:00:12
    	progress: |============--------------------------------------| 24.8% Complete  => 0:00:12
    	progress: |=============-------------------------------------| 25.5% Complete  => 0:00:12
    	progress: |=============-------------------------------------| 26.1% Complete  => 0:00:12
    	progress: |=============-------------------------------------| 26.7% Complete  => 0:00:12
    	progress: |==============------------------------------------| 27.3% Complete  => 0:00:12
    	progress: |==============------------------------------------| 28.0% Complete  => 0:00:12
    	progress: |==============------------------------------------| 28.6% Complete  => 0:00:12
    	progress: |===============-----------------------------------| 29.2% Complete  => 0:00:12
    	progress: |===============-----------------------------------| 29.8% Complete  => 0:00:12
    	progress: |===============-----------------------------------| 30.4% Complete  => 0:00:12
    	progress: |================----------------------------------| 31.1% Complete  => 0:00:12
    	progress: |================----------------------------------| 31.7% Complete  => 0:00:12
    	progress: |================----------------------------------| 32.3% Complete  => 0:00:12
    	progress: |================----------------------------------| 32.9% Complete  => 0:00:12
    	progress: |=================---------------------------------| 33.5% Complete  => 0:00:12
    	progress: |=================---------------------------------| 34.2% Complete  => 0:00:12
    	progress: |=================---------------------------------| 34.8% Complete  => 0:00:12
    	progress: |==================--------------------------------| 35.4% Complete  => 0:00:12
    	progress: |==================--------------------------------| 36.0% Complete  => 0:00:12
    	progress: |==================--------------------------------| 36.6% Complete  => 0:00:12
    	progress: |===================-------------------------------| 37.3% Complete  => 0:00:12
    	progress: |===================-------------------------------| 37.9% Complete  => 0:00:12
    	progress: |===================-------------------------------| 38.5% Complete  => 0:00:12
    	progress: |====================------------------------------| 39.1% Complete  => 0:00:12
    	progress: |====================------------------------------| 39.8% Complete  => 0:00:12
    	progress: |====================------------------------------| 40.4% Complete  => 0:00:12
    	progress: |====================------------------------------| 41.0% Complete  => 0:00:12
    	progress: |=====================-----------------------------| 41.6% Complete  => 0:00:12
    	progress: |=====================-----------------------------| 42.2% Complete  => 0:00:12
    	progress: |=====================-----------------------------| 42.9% Complete  => 0:00:12
    	progress: |======================----------------------------| 43.5% Complete  => 0:00:12
    	progress: |======================----------------------------| 44.1% Complete  => 0:00:12
    	progress: |======================----------------------------| 44.7% Complete  => 0:00:12
    	progress: |=======================---------------------------| 45.3% Complete  => 0:00:12
    	progress: |=======================---------------------------| 46.0% Complete  => 0:00:12
    	progress: |=======================---------------------------| 46.6% Complete  => 0:00:12
    	progress: |========================--------------------------| 47.2% Complete  => 0:00:12
    	progress: |========================--------------------------| 47.8% Complete  => 0:00:12
    	progress: |========================--------------------------| 48.4% Complete  => 0:00:12
    	progress: |=========================-------------------------| 49.1% Complete  => 0:00:12
    	progress: |=========================-------------------------| 49.7% Complete  => 0:00:12
    	progress: |=========================-------------------------| 50.3% Complete  => 0:00:12
    	progress: |=========================-------------------------| 50.9% Complete  => 0:00:12
    	progress: |==========================------------------------| 51.6% Complete  => 0:00:12
    	progress: |==========================------------------------| 52.2% Complete  => 0:00:12
    	progress: |==========================------------------------| 52.8% Complete  => 0:00:12
    	progress: |===========================-----------------------| 53.4% Complete  => 0:00:12
    	progress: |===========================-----------------------| 54.0% Complete  => 0:00:12
    	progress: |===========================-----------------------| 54.7% Complete  => 0:00:12
    	progress: |============================----------------------| 55.3% Complete  => 0:00:12
    	progress: |============================----------------------| 55.9% Complete  => 0:00:12
    	progress: |============================----------------------| 56.5% Complete  => 0:00:12
    	progress: |=============================---------------------| 57.1% Complete  => 0:00:12
    	progress: |=============================---------------------| 57.8% Complete  => 0:00:12
    	progress: |=============================---------------------| 58.4% Complete  => 0:00:12
    	progress: |==============================--------------------| 59.0% Complete  => 0:00:12
    	progress: |==============================--------------------| 59.6% Complete  => 0:00:12
    	progress: |==============================--------------------| 60.2% Complete  => 0:00:12
    	progress: |==============================--------------------| 60.9% Complete  => 0:00:12
    	progress: |===============================-------------------| 61.5% Complete  => 0:00:12
    	progress: |===============================-------------------| 62.1% Complete  => 0:00:12
    	progress: |===============================-------------------| 62.7% Complete  => 0:00:12
    	progress: |================================------------------| 63.4% Complete  => 0:00:12
    	progress: |================================------------------| 64.0% Complete  => 0:00:12
    	progress: |================================------------------| 64.6% Complete  => 0:00:12
    	progress: |=================================-----------------| 65.2% Complete  => 0:00:12
    	progress: |=================================-----------------| 65.8% Complete  => 0:00:12
    	progress: |=================================-----------------| 66.5% Complete  => 0:00:12
    	progress: |==================================----------------| 67.1% Complete  => 0:00:12
    	progress: |==================================----------------| 67.7% Complete  => 0:00:12
    	progress: |==================================----------------| 68.3% Complete  => 0:00:12
    	progress: |==================================----------------| 68.9% Complete  => 0:00:12
    	progress: |===================================---------------| 69.6% Complete  => 0:00:12
    	progress: |===================================---------------| 70.2% Complete  => 0:00:12
    	progress: |===================================---------------| 70.8% Complete  => 0:00:12
    	progress: |====================================--------------| 71.4% Complete  => 0:00:12
    	progress: |====================================--------------| 72.0% Complete  => 0:00:12
    	progress: |====================================--------------| 72.7% Complete  => 0:00:12
    	progress: |=====================================-------------| 73.3% Complete  => 0:00:12
    	progress: |=====================================-------------| 73.9% Complete  => 0:00:12
    	progress: |=====================================-------------| 74.5% Complete  => 0:00:12
    	progress: |======================================------------| 75.2% Complete  => 0:00:12
    	progress: |======================================------------| 75.8% Complete  => 0:00:12
    	progress: |======================================------------| 76.4% Complete  => 0:00:12
    	progress: |=======================================-----------| 77.0% Complete  => 0:00:12
    	progress: |=======================================-----------| 77.6% Complete  => 0:00:12
    	progress: |=======================================-----------| 78.3% Complete  => 0:00:12
    	progress: |=======================================-----------| 78.9% Complete  => 0:00:12
    	progress: |========================================----------| 79.5% Complete  => 0:00:12
    	progress: |========================================----------| 80.1% Complete  => 0:00:12
    	progress: |========================================----------| 80.7% Complete  => 0:00:12
    	progress: |=========================================---------| 81.4% Complete  => 0:00:12
    	progress: |=========================================---------| 82.0% Complete  => 0:00:12
    	progress: |=========================================---------| 82.6% Complete  => 0:00:12
    	progress: |==========================================--------| 83.2% Complete  => 0:00:12
    	progress: |==========================================--------| 83.9% Complete  => 0:00:12
    	progress: |==========================================--------| 84.5% Complete  => 0:00:12
    	progress: |===========================================-------| 85.1% Complete  => 0:00:12
    	progress: |===========================================-------| 85.7% Complete  => 0:00:12
    	progress: |===========================================-------| 86.3% Complete  => 0:00:12
    	progress: |===========================================-------| 87.0% Complete  => 0:00:12
    	progress: |============================================------| 87.6% Complete  => 0:00:12
    	progress: |============================================------| 88.2% Complete  => 0:00:12
    	progress: |============================================------| 88.8% Complete  => 0:00:12
    	progress: |=============================================-----| 89.4% Complete  => 0:00:12
    	progress: |=============================================-----| 90.1% Complete  => 0:00:12
    	progress: |=============================================-----| 90.7% Complete  => 0:00:12
    	progress: |==============================================----| 91.3% Complete  => 0:00:12
    	progress: |==============================================----| 91.9% Complete  => 0:00:12
    	progress: |==============================================----| 92.5% Complete  => 0:00:12
    	progress: |===============================================---| 93.2% Complete  => 0:00:12
    	progress: |===============================================---| 93.8% Complete  => 0:00:12
    	progress: |===============================================---| 94.4% Complete  => 0:00:12
    	progress: |================================================--| 95.0% Complete  => 0:00:12
    	progress: |================================================--| 95.7% Complete  => 0:00:12
    	progress: |================================================--| 96.3% Complete  => 0:00:12
    	progress: |================================================--| 96.9% Complete  => 0:00:12
    	progress: |=================================================-| 97.5% Complete  => 0:00:12
    	progress: |=================================================-| 98.1% Complete  => 0:00:12
    	progress: |=================================================-| 98.8% Complete  => 0:00:12
    	progress: |==================================================| 99.4% Complete  => 0:00:12
    	progress: |==================================================| 100.0% Complete  => 0:00:12

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

## tests/test_spatial_transform.py 17 0:00:37.395804

### PASSED Test_Geometry_Transformer::test_to_map_geometry 0:00:01.917584

Started | 2025-09-10 17:21:14
Ended | 2025-09-10 17:21:16
Duration | 0:00:01.917584
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:21:14:   Reading Input Data
    2025/09/10 17:21:14:   Reading metadata for VNIR detector...
    2025/09/10 17:21:14:   Calculating solar irradiance...
    2025/09/10 17:21:14:   Reading metadata for SWIR detector...
    2025/09/10 17:21:15:   Calculating solar irradiance...
    2025/09/10 17:21:15:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:21:15:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:21:15:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_Geometry_Transformer::test_to_sensor_geometry 0:00:01.309172

Started | 2025-09-10 17:21:16
Ended | 2025-09-10 17:21:17
Duration | 0:00:01.309172
Markers |
Fixtures | request

#### Setup

#### Call

##### Captured stdout call

    2025/09/10 17:21:16:   Reading Input Data
    2025/09/10 17:21:16:   Reading metadata for VNIR detector...
    2025/09/10 17:21:16:   Calculating solar irradiance...
    2025/09/10 17:21:16:   Reading metadata for SWIR detector...
    2025/09/10 17:21:17:   Calculating solar irradiance...
    2025/09/10 17:21:17:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:21:17:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:21:17:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...

##### Captured log call

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2D 0:00:02.395682

Started | 2025-09-10 17:21:17
Ended | 2025-09-10 17:21:19
Duration | 0:00:02.395682
Markers |
Fixtures | request

#### Setup

##### Captured stdout setup

    2025/09/10 17:21:17:   Reading Input Data
    2025/09/10 17:21:17:   Reading metadata for VNIR detector...
    2025/09/10 17:21:18:   Calculating solar irradiance...
    2025/09/10 17:21:18:   Reading metadata for SWIR detector...
    2025/09/10 17:21:18:   Calculating solar irradiance...
    2025/09/10 17:21:18:   Reading image masks in VNIR sensor geometry.
    2025/09/10 17:21:18:   Converting DN values to radiance [mW/m^2/sr/nm] for VNIR detector...
    2025/09/10 17:21:19:   Converting DN values to radiance [mW/m^2/sr/nm] for SWIR detector...
    2025/09/10 17:21:19:   Computing VNIR geolayer...
    2025/09/10 17:21:19:   Computing SWIR geolayer...

##### Captured stderr setup

    2025/09/10 17:21:17:   The input EnMAP Level-1B image was processed with an old version of the ground segment processing system (version 00.02.04), which, e.g. did not include de-striping. It is highly recommended to re-download the dataset in the latest processing version from the archive via the EOWEB GeoPortal (www.eoweb.dlr.de) before passing it to EnPT.

##### Captured log setup

    INFO     enpt.io.reader:reader.py:82 Reading Input Data

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_2DGeolayer 0:00:00.433895

Started | 2025-09-10 17:21:19
Ended | 2025-09-10 17:21:20
Duration | 0:00:00.433895
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_SWIR_to_VNIR_2band3DInput_3DGeolayer 0:00:00.394529

Started | 2025-09-10 17:21:20
Ended | 2025-09-10 17:21:20
Duration | 0:00:00.394529
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_2D 0:00:00.393567

Started | 2025-09-10 17:21:20
Ended | 2025-09-10 17:21:21
Duration | 0:00:00.393567
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_VNIR_SWIR_SensorGeometryTransformer::test_transform_sensorgeo_VNIR_to_SWIR_3D 0:00:23.364664

Started | 2025-09-10 17:21:21
Ended | 2025-09-10 17:21:44
Duration | 0:00:23.364664
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer 0:00:00.428718

Started | 2025-09-10 17:21:44
Ended | 2025-09-10 17:21:44
Duration | 0:00:00.428718
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:00.371689

Started | 2025-09-10 17:21:44
Ended | 2025-09-10 17:21:45
Duration | 0:00:00.371689
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_compute_normalized_image_coordinates 0:00:00.003848

Started | 2025-09-10 17:21:45
Ended | 2025-09-10 17:21:45
Duration | 0:00:00.003848
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_normalize_coordinates 0:00:00.002710

Started | 2025-09-10 17:21:45
Ended | 2025-09-10 17:21:45
Duration | 0:00:00.002710
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_Geolayer_Generator::test_transform_LonLatHeight_to_RowCol 0:00:00.002977

Started | 2025-09-10 17:21:45
Ended | 2025-09-10 17:21:45
Duration | 0:00:00.002977
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_average_elevation 0:00:02.022354

Started | 2025-09-10 17:21:45
Ended | 2025-09-10 17:21:47
Duration | 0:00:02.022354
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_faulty_coeff_set 0:00:00.484841

Test in case of a faulty/inaccurate coeff set the result really does not contain NaNs.

NOTE: NaNs should be filled automatically.

Started | 2025-09-10 17:21:47
Ended | 2025-09-10 17:21:47
Duration | 0:00:00.484841
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_multiprocessing 0:00:02.086872

Started | 2025-09-10 17:21:47
Ended | 2025-09-10 17:21:49
Duration | 0:00:02.086872
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_multiple_coeff_sets_singleprocessing 0:00:01.354146

Started | 2025-09-10 17:21:49
Ended | 2025-09-10 17:21:51
Duration | 0:00:01.354146
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

### PASSED Test_RPC_3D_Geolayer_Generator::test_compute_geolayer_one_unique_coeff_set 0:00:00.428557

Started | 2025-09-10 17:21:51
Ended | 2025-09-10 17:21:51
Duration | 0:00:00.428557
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown

## tests/test_srf.py 1 0:00:00.005471

### PASSED Test_SRF::test_from_cwl_fwhm 0:00:00.005471

Started | 2025-09-10 17:21:51
Ended | 2025-09-10 17:21:51
Duration | 0:00:00.005471
Markers |
Fixtures | request

#### Setup

#### Call

#### Teardown